@@ -29,9 +29,7 @@
    * module and jQuery (for table drawer slide animation in IE9) to be installed.
    */
   angular
-    .module('horizon.framework.widgets.table', [
-      'smart-table', 'lrDragNDrop'
-    ])
+    .module('horizon.framework.widgets.table', [])
 
     /**
      * @ngdoc parameters
