@@ -14,7 +14,8 @@
       'horizon.framework.widgets.action-list',
       'horizon.framework.widgets.metadata',
       'horizon.framework.widgets.toast',
-      'MagicSearch'
+      'horizon.framework.widgets.magic-search',
+      'horizon.framework.widgets.load-edit'
     ])
     .config(config);
 
