@@ -57,34 +57,24 @@ horizon.forms = {
   },
 
   handle_subnet_address_source: function() {
-    $("div.table_wrapper, #modal_wrapper").on("change", "select#id_address_source", function(evt) {
+    $("div.table_wrapper, #modal_wrapper").on("change", "select#id_address_source", function() {
       var $option = $(this).find("option:selected");
       var $form = $(this).closest("form");
       var $ipVersion = $form.find("select#id_ip_version");
       if ($option.val() == "subnetpool") {
         $ipVersion.attr("disabled", "disabled");
-        // disabled fields do not post, store the value in a hidden input
-        var el = document.createElement("input");
-        el.type='hidden';
-        el.id = "id_hidden_ip_version";
-        el.name = $ipVersion.attr('name');
-        el.value = $ipVersion.attr('value');
-        $form.append(el);
       } else {
-        var $hiddenIpVersion = $form.find("hidden#id_hidden_ip_version");
-        $hiddenIpVersion.remove();
         $ipVersion.removeAttr("disabled");
       }
     });
   },
 
   handle_subnet_subnetpool: function() {
-    $("div.table_wrapper, #modal_wrapper").on("change", "select#id_subnetpool", function(evt) {
+    $("div.table_wrapper, #modal_wrapper").on("change", "select#id_subnetpool", function() {
       var $option = $(this).find("option:selected");
       var $form = $(this).closest("form");
       var $ipVersion = $form.find("select#id_ip_version");
       var $prefixLength = $form.find("select#id_prefixlen");
-      var $ipv6Modes = $form.find("select#id_ipv6_modes");
       var subnetpoolIpVersion = parseInt($option.data("ip_version"), 10) || 4;
       var minPrefixLen = parseInt($option.data("min_prefixlen"), 10) || 1;
       var maxPrefixLen = parseInt($option.data("max_prefixlen"), 10);
@@ -178,18 +168,24 @@ horizon.forms = {
   }
 };
 
-horizon.forms.prevent_multiple_submission = function (el) {
-  // Disable multiple submissions when launching a form.
+horizon.forms.handle_submit = function (el) {
   var $form = $(el).find("form");
   $form.submit(function () {
-    var button = $(this).find('[type="submit"]');
+    var $this = $(this);
+    // Disable multiple submissions when launching a form.
+    var button = $this.find('[type="submit"]');
     if (button.hasClass('btn-primary') && !button.hasClass('always-enabled')){
-      $(this).submit(function () {
+      $this.submit(function () {
         return false;
       });
       button.removeClass('primary').addClass('disabled');
       button.attr('disabled', 'disabled');
     }
+    // Remove disabled attribute on select fields before submit to get value
+    // included in POST request.
+    $this.find('select[disabled="disabled"]').each(function (i, field) {
+      $(field).removeAttr("disabled");
+    });
     return true;
   });
 };
@@ -241,14 +237,11 @@ horizon.forms.init_examples = function (el) {
 
   // Update/create image form.
   $el.find("#create_image_form input#id_copy_from").attr("placeholder", "http://example.com/image.iso");
-
-  // Table search box.
-  $el.find(".table_search input").attr("placeholder", gettext("Filter"));
 };
 
 horizon.addInitFunction(horizon.forms.init = function () {
-  horizon.forms.prevent_multiple_submission($('body'));
-  horizon.modals.addModalInitFunction(horizon.forms.prevent_multiple_submission);
+  horizon.forms.handle_submit($('body'));
+  horizon.modals.addModalInitFunction(horizon.forms.handle_submit);
 
   horizon.forms.init_examples($("body"));
   horizon.modals.addModalInitFunction(horizon.forms.init_examples);
@@ -321,7 +314,7 @@ horizon.addInitFunction(horizon.forms.init = function () {
 
     $switchables.each(function (index, switchable) {
       var $switchable = $(switchable),
-        visible = $switchable.is(':visible'),
+        visible = $switchable.parent().hasClass('themable-checkbox') ? $switchable.siblings('label').is(':visible') : $switchable.is(':visible'),
         slug = $switchable.data('slug'),
         checked = $switchable.prop('checked'),
         hide_tab = String($switchable.data('hide-tab')).split(','),
