@@ -28,16 +28,6 @@ var Horizon = function () {
     initFunctions = [];
   };
 
-  /* An utility function for escaping HTML to avoid XSS. */
-  horizon.escape_html = function (text) {
-    return text.replace(/&/g, '&amp;')
-      .replace(/</g, '&lt;')
-      .replace(/>/g, '&gt;')
-      .replace(/"/g, '&quot;')
-      .replace(/'/g, '&#x27;')
-      .replace(/\//g, '&#x2F;');
-  };
-
   /* Storage for backend configuration variables which the frontend
    * should be aware of.
    */
@@ -47,4 +37,6 @@ var Horizon = function () {
 };
 
 // Create the one and only horizon object.
+/*eslint-disable no-unused-vars */
 var horizon = new Horizon();
+/*eslint-enable no-unused-vars */
