@@ -80,6 +80,9 @@ horizon.modals.init_wizard = function () {
       $group.find('span.help-block.alert').remove();
     });
 
+    // Temporarilly remove "disabled" attribute to get the values serialized
+    var disabled = $form.find('select[disabled="disabled"]').removeAttr("disabled");
+
     // Send the data for validation.
     $.ajax({
       type: 'POST',
@@ -94,6 +97,9 @@ horizon.modals.init_wizard = function () {
       success: function (data) { response = data; }
     });
 
+    // Re-enable the "disabled" attribute on disabled inputs.
+    disabled.attr("disabled", "disabled");
+
     // Handle errors.
     if (response.has_errors) {
       var first_field = true;
@@ -306,13 +312,8 @@ horizon.addInitFunction(horizon.modals.init = function() {
     horizon.datatables.validate_button($(modal).find(".table_wrapper > form"));
   });
 
-  function loadAngular(element) {
-    try {
-      $compile(element)($rootScope);
-      $rootScope.$apply();
-    } catch (err) {}
-  }
-  horizon.modals.addModalInitFunction(loadAngular);
+  // Compile angular directives in the modal DOM
+  horizon.modals.addModalInitFunction(horizon.utils.loadAngular);
 
   // Load modals for ajax-modal links.
   $document.on('click', '.ajax-modal', function (evt) {
