@@ -21,7 +21,7 @@ from django.conf import settings
 from django.contrib.auth.models import User  # noqa
 from django.core.exceptions import ImproperlyConfigured  # noqa
 from django.core import urlresolvers
-from django.utils.importlib import import_module  # noqa
+from importlib import import_module
 from six import moves
 
 import six
@@ -338,10 +338,10 @@ class GetUserHomeTests(BaseHorizonTests):
         conf.HORIZON_CONFIG._setup()
 
     def test_using_callable(self):
-        def fancy_user_fnc(user):
+        def themable_user_fnc(user):
             return user.username.upper()
 
-        settings.HORIZON_CONFIG['user_home'] = fancy_user_fnc
+        settings.HORIZON_CONFIG['user_home'] = themable_user_fnc
         conf.HORIZON_CONFIG._setup()
 
         self.assertEqual(self.test_user.username.upper(),
