@@ -17,7 +17,6 @@
 #    under the License.
 
 from collections import Sequence  # noqa
-import logging
 
 from django.conf import settings
 
@@ -30,9 +29,6 @@ __all__ = ('APIResourceWrapper', 'APIDictWrapper',
            'get_service_from_catalog', 'url_for',)
 
 
-LOG = logging.getLogger(__name__)
-
-
 class APIVersionManager(object):
     """Object to store and manage API versioning data and utility methods."""
 
