@@ -26,10 +26,11 @@ from django.conf import settings
 from django.utils.translation import pgettext_lazy
 from django.utils.translation import ugettext_lazy as _
 
-from cinderclient.exceptions import ClientException  # noqa
+from cinderclient import exceptions as cinder_exception
 from cinderclient.v2.contrib import list_extensions as cinder_list_extensions
 
 from horizon import exceptions
+from horizon.utils import functions as utils
 from horizon.utils.memoized import memoized  # noqa
 
 from openstack_dashboard.api import base
@@ -79,8 +80,9 @@ class Volume(BaseCinderAPIResourceWrapper):
     _attrs = ['id', 'name', 'description', 'size', 'status', 'created_at',
               'volume_type', 'availability_zone', 'imageRef', 'bootable',
               'snapshot_id', 'source_volid', 'attachments', 'tenant_name',
-              'os-vol-host-attr:host', 'os-vol-tenant-attr:tenant_id',
-              'metadata', 'volume_image_metadata', 'encrypted', 'transfer']
+              'consistencygroup_id', 'os-vol-host-attr:host',
+              'os-vol-tenant-attr:tenant_id', 'metadata',
+              'volume_image_metadata', 'encrypted', 'transfer']
 
     @property
     def is_bootable(self):
@@ -96,10 +98,17 @@ class VolumeSnapshot(BaseCinderAPIResourceWrapper):
 
 class VolumeType(BaseCinderAPIResourceWrapper):
 
-    _attrs = ['id', 'name', 'extra_specs', 'created_at',
+    _attrs = ['id', 'name', 'extra_specs', 'created_at', 'encryption',
+              'associated_qos_spec', 'description',
               'os-extended-snapshot-attributes:project_id']
 
 
+class VolumeConsistencyGroup(BaseCinderAPIResourceWrapper):
+
+    _attrs = ['id', 'name', 'description', 'status', 'availability_zone',
+              'created_at', 'volume_types']
+
+
 class VolumeBackup(BaseCinderAPIResourceWrapper):
 
     _attrs = ['id', 'name', 'description', 'container', 'size', 'status',
@@ -115,6 +124,11 @@ class VolumeBackup(BaseCinderAPIResourceWrapper):
         self._volume = value
 
 
+class QosSpecs(BaseCinderAPIResourceWrapper):
+
+    _attrs = ['id', 'name', 'consumer', 'specs']
+
+
 class VolTypeExtraSpec(object):
     def __init__(self, type_id, key, val):
         self.type_id = type_id
@@ -188,25 +202,67 @@ def version_get():
     return api_version['version']
 
 
-def volume_list(request, search_opts=None):
+def volume_list(request, search_opts=None, marker=None, sort_dir="desc"):
+    volumes, _, __ = volume_list_paged(
+        request, search_opts=search_opts, marker=marker, paginate=False,
+        sort_dir=sort_dir)
+    return volumes
+
+
+def update_pagination(entities, page_size, marker, sort_dir):
+    has_more_data, has_prev_data = False, False
+    if len(entities) > page_size:
+        has_more_data = True
+        entities.pop()
+        if marker is not None:
+            has_prev_data = True
+    # first page condition when reached via prev back
+    elif sort_dir == 'asc' and marker is not None:
+        has_more_data = True
+    # last page condition
+    elif marker is not None:
+        has_prev_data = True
+
+    return entities, has_more_data, has_prev_data
+
+
+def volume_list_paged(request, search_opts=None, marker=None, paginate=False,
+                      sort_dir="desc"):
     """To see all volumes in the cloud as an admin you can pass in a special
     search option: {'all_tenants': 1}
     """
+    has_more_data = False
+    has_prev_data = False
+    volumes = []
 
     c_client = cinderclient(request)
     if c_client is None:
-        return []
+        return volumes, has_more_data, has_prev_data
 
     # build a dictionary of volume_id -> transfer
     transfers = {t.volume_id: t
                  for t in transfer_list(request, search_opts=search_opts)}
 
-    volumes = []
-    for v in c_client.volumes.list(search_opts=search_opts):
-        v.transfer = transfers.get(v.id)
-        volumes.append(Volume(v))
+    if VERSIONS.active > 1 and paginate:
+        page_size = utils.get_page_size(request)
+        # sort_key and sort_dir deprecated in kilo, use sort
+        # if pagination is true, we use a single sort parameter
+        # by default, it is "created_at"
+        sort = 'created_at:' + sort_dir
+        for v in c_client.volumes.list(search_opts=search_opts,
+                                       limit=page_size + 1,
+                                       marker=marker,
+                                       sort=sort):
+            v.transfer = transfers.get(v.id)
+            volumes.append(Volume(v))
+        volumes, has_more_data, has_prev_data = update_pagination(
+            volumes, page_size, marker, sort_dir)
+    else:
+        for v in c_client.volumes.list(search_opts=search_opts):
+            v.transfer = transfers.get(v.id)
+            volumes.append(Volume(v))
 
-    return volumes
+    return volumes, has_more_data, has_prev_data
 
 
 def volume_get(request, volume_id):
@@ -293,10 +349,12 @@ def volume_get_encryption_metadata(request, volume_id):
     return cinderclient(request).volumes.get_encryption_metadata(volume_id)
 
 
-def volume_migrate(request, volume_id, host, force_host_copy=False):
+def volume_migrate(request, volume_id, host, force_host_copy=False,
+                   lock_volume=False):
     return cinderclient(request).volumes.migrate_volume(volume_id,
                                                         host,
-                                                        force_host_copy)
+                                                        force_host_copy,
+                                                        lock_volume)
 
 
 def volume_snapshot_get(request, snapshot_id):
@@ -305,11 +363,40 @@ def volume_snapshot_get(request, snapshot_id):
 
 
 def volume_snapshot_list(request, search_opts=None):
+    snapshots, _, __ = volume_snapshot_list_paged(request,
+                                                  search_opts=search_opts,
+                                                  paginate=False)
+    return snapshots
+
+
+def volume_snapshot_list_paged(request, search_opts=None, marker=None,
+                               paginate=False, sort_dir="desc"):
+    has_more_data = False
+    has_prev_data = False
+    snapshots = []
     c_client = cinderclient(request)
     if c_client is None:
-        return []
-    return [VolumeSnapshot(s) for s in c_client.volume_snapshots.list(
-        search_opts=search_opts)]
+        return snapshots, has_more_data, has_more_data
+
+    if VERSIONS.active > 1 and paginate:
+        page_size = utils.get_page_size(request)
+        # sort_key and sort_dir deprecated in kilo, use sort
+        # if pagination is true, we use a single sort parameter
+        # by default, it is "created_at"
+        sort = 'created_at:' + sort_dir
+        for s in c_client.volume_snapshots.list(search_opts=search_opts,
+                                                limit=page_size + 1,
+                                                marker=marker,
+                                                sort=sort):
+            snapshots.append(VolumeSnapshot(s))
+
+        snapshots, has_more_data, has_prev_data = update_pagination(
+            snapshots, page_size, marker, sort_dir)
+    else:
+        for s in c_client.volume_snapshots.list(search_opts=search_opts):
+            snapshots.append(VolumeSnapshot(s))
+
+    return snapshots, has_more_data, has_prev_data
 
 
 def volume_snapshot_create(request, volume_id, name,
@@ -340,6 +427,59 @@ def volume_snapshot_reset_state(request, snapshot_id, state):
         snapshot_id, state)
 
 
+def volume_cgroup_get(request, cgroup_id):
+    cgroup = cinderclient(request).consistencygroups.get(cgroup_id)
+    return VolumeConsistencyGroup(cgroup)
+
+
+def volume_cgroup_list(request, search_opts=None):
+    c_client = cinderclient(request)
+    if c_client is None:
+        return []
+    return [VolumeConsistencyGroup(s) for s in c_client.consistencygroups.list(
+        search_opts=search_opts)]
+
+
+def volume_cgroup_list_with_vol_type_names(request, search_opts=None):
+    cgroups = volume_cgroup_list(request, search_opts)
+    for cgroup in cgroups:
+        cgroup.volume_type_names = []
+        for vol_type_id in cgroup.volume_types:
+            vol_type = volume_type_get(request, vol_type_id)
+            cgroup.volume_type_names.append(vol_type.name)
+
+    return cgroups
+
+
+def volume_cgroup_create(request, volume_types, name,
+                         description=None, availability_zone=None):
+    return VolumeConsistencyGroup(
+        cinderclient(request).consistencygroups.create(
+            volume_types,
+            name,
+            description,
+            availability_zone=availability_zone))
+
+
+def volume_cgroup_delete(request, cgroup_id, force=False):
+    return cinderclient(request).consistencygroups.delete(cgroup_id, force)
+
+
+def volume_cgroup_update(request, cgroup_id, name=None, description=None,
+                         add_vols=None, remove_vols=None):
+    cgroup_data = {}
+    if name:
+        cgroup_data['name'] = name
+    if description:
+        cgroup_data['description'] = description
+    if add_vols:
+        cgroup_data['add_volumes'] = add_vols
+    if remove_vols:
+        cgroup_data['remove_volumes'] = remove_vols
+    return cinderclient(request).consistencygroups.update(cgroup_id,
+                                                          **cgroup_data)
+
+
 @memoized
 def volume_backup_supported(request):
     """This method will determine if cinder supports backup.
@@ -358,10 +498,38 @@ def volume_backup_get(request, backup_id):
 
 
 def volume_backup_list(request):
+    backups, _, __ = volume_backup_list_paged(request, paginate=False)
+    return backups
+
+
+def volume_backup_list_paged(request, marker=None, paginate=False,
+                             sort_dir="desc"):
+    has_more_data = False
+    has_prev_data = False
+    backups = []
+
     c_client = cinderclient(request)
     if c_client is None:
-        return []
-    return [VolumeBackup(b) for b in c_client.backups.list()]
+        return backups, has_more_data, has_prev_data
+
+    if VERSIONS.active > 1 and paginate:
+        page_size = utils.get_page_size(request)
+        # sort_key and sort_dir deprecated in kilo, use sort
+        # if pagination is true, we use a single sort parameter
+        # by default, it is "created_at"
+        sort = 'created_at:' + sort_dir
+        for b in c_client.backups.list(limit=page_size + 1,
+                                       marker=marker,
+                                       sort=sort):
+            backups.append(VolumeBackup(b))
+
+        backups, has_more_data, has_prev_data = update_pagination(
+            backups, page_size, marker, sort_dir)
+    else:
+        for b in c_client.backups.list():
+            backups.append(VolumeBackup(b))
+
+    return backups, has_more_data, has_prev_data
 
 
 def volume_backup_create(request,
@@ -485,12 +653,17 @@ def volume_type_update(request, volume_type_id, name=None, description=None):
                                                      description)
 
 
+@memoized
 def volume_type_default(request):
     return cinderclient(request).volume_types.default()
 
 
 def volume_type_delete(request, volume_type_id):
-    return cinderclient(request).volume_types.delete(volume_type_id)
+    try:
+        return cinderclient(request).volume_types.delete(volume_type_id)
+    except cinder_exception.BadRequest:
+        raise exceptions.BadRequest(_(
+            "This volume type is used by one or more volumes."))
 
 
 def volume_type_get(request, volume_type_id):
@@ -514,6 +687,11 @@ def volume_encryption_type_list(request):
     return cinderclient(request).volume_encryption_types.list()
 
 
+def volume_encryption_type_update(request, volume_type_id, data):
+    return cinderclient(request).volume_encryption_types.update(volume_type_id,
+                                                                specs=data)
+
+
 def volume_type_extra_get(request, type_id, raw=False):
     vol_type = volume_type_get(request, type_id)
     extras = vol_type.get_keys()
@@ -580,6 +758,10 @@ def qos_spec_get_associations(request, qos_spec_id):
     return cinderclient(request).qos_specs.get_associations(qos_spec_id)
 
 
+def qos_specs_list(request):
+    return [QosSpecs(s) for s in qos_spec_list(request)]
+
+
 @memoized
 def tenant_absolute_limits(request):
     limits = cinderclient(request).limits.get().absolute
@@ -630,8 +812,12 @@ def transfer_list(request, detailed=True, search_opts=None):
     search option: {'all_tenants': 1}
     """
     c_client = cinderclient(request)
-    return [VolumeTransfer(v) for v in c_client.transfers.list(
-        detailed=detailed, search_opts=search_opts)]
+    try:
+        return [VolumeTransfer(v) for v in c_client.transfers.list(
+            detailed=detailed, search_opts=search_opts)]
+    except cinder_exception.Forbidden as error:
+        LOG.error(error)
+        return []
 
 
 def transfer_get(request, transfer_id):
@@ -659,3 +845,10 @@ def pool_list(request, detailed=False):
 
     return [VolumePool(v) for v in c_client.pools.list(
         detailed=detailed)]
+
+
+def is_volume_service_enabled(request):
+    return bool(
+        base.is_service_enabled(request, 'volume') or
+        base.is_service_enabled(request, 'volumev2')
+    )
