@@ -30,6 +30,7 @@ from neutronclient.common import exceptions as neutron_exc
 from neutronclient.v2_0 import client as neutron_client
 import six
 
+from horizon import exceptions
 from horizon import messages
 from horizon.utils.memoized import memoized  # noqa
 from openstack_dashboard.api import base
@@ -51,27 +52,23 @@ ROUTER_INTERFACE_OWNERS = (
 )
 
 
-def _init_apiresource(apiresource):
-    """Handle common initialization of apiresource.
-
-        Note: the dictionary is modified in place.
-    """
-
-    if apiresource['admin_state_up']:
-        apiresource['admin_state'] = 'UP'
-    else:
-        apiresource['admin_state'] = 'DOWN'
-
-    # Django cannot handle a key name with ':', so use '__'.
-    apiresource.update({
-        key.replace(':', '__'): value
-        for key, value in apiresource.items()
-        if ':' in key
-    })
-
-
 class NeutronAPIDictWrapper(base.APIDictWrapper):
 
+    def __init__(self, apidict):
+        if 'admin_state_up' in apidict:
+            if apidict['admin_state_up']:
+                apidict['admin_state'] = 'UP'
+            else:
+                apidict['admin_state'] = 'DOWN'
+
+        # Django cannot handle a key name with ':', so use '__'.
+        apidict.update({
+            key.replace(':', '__'): value
+            for key, value in apidict.items()
+            if ':' in key
+        })
+        super(NeutronAPIDictWrapper, self).__init__(apidict)
+
     def set_id_as_name_if_empty(self, length=8):
         try:
             if not self._apidict['name']:
@@ -94,18 +91,10 @@ class NeutronAPIDictWrapper(base.APIDictWrapper):
 class Agent(NeutronAPIDictWrapper):
     """Wrapper for neutron agents."""
 
-    def __init__(self, apiresource):
-        _init_apiresource(apiresource)
-        super(Agent, self).__init__(apiresource)
-
 
 class Network(NeutronAPIDictWrapper):
     """Wrapper for neutron Networks."""
 
-    def __init__(self, apiresource):
-        _init_apiresource(apiresource)
-        super(Network, self).__init__(apiresource)
-
     def to_dict(self):
         d = dict(super(NeutronAPIDictWrapper, self).to_dict())
         d['subnets'] = [s.to_dict() for s in d['subnets']]
@@ -115,9 +104,9 @@ class Network(NeutronAPIDictWrapper):
 class Subnet(NeutronAPIDictWrapper):
     """Wrapper for neutron subnets."""
 
-    def __init__(self, apiresource):
-        apiresource['ipver_str'] = get_ipver_str(apiresource['ip_version'])
-        super(Subnet, self).__init__(apiresource)
+    def __init__(self, apidict):
+        apidict['ipver_str'] = get_ipver_str(apidict['ip_version'])
+        super(Subnet, self).__init__(apidict)
 
 
 class SubnetPool(NeutronAPIDictWrapper):
@@ -127,12 +116,11 @@ class SubnetPool(NeutronAPIDictWrapper):
 class Port(NeutronAPIDictWrapper):
     """Wrapper for neutron ports."""
 
-    def __init__(self, apiresource):
-        _init_apiresource(apiresource)
-        if 'mac_learning_enabled' in apiresource:
-            apiresource['mac_state'] = \
-                ON_STATE if apiresource['mac_learning_enabled'] else OFF_STATE
-        super(Port, self).__init__(apiresource)
+    def __init__(self, apidict):
+        if 'mac_learning_enabled' in apidict:
+            apidict['mac_state'] = \
+                ON_STATE if apidict['mac_learning_enabled'] else OFF_STATE
+        super(Port, self).__init__(apidict)
 
 
 class Profile(NeutronAPIDictWrapper):
@@ -140,17 +128,10 @@ class Profile(NeutronAPIDictWrapper):
     _attrs = ['profile_id', 'name', 'segment_type', 'segment_range',
               'sub_type', 'multicast_ip_index', 'multicast_ip_range']
 
-    def __init__(self, apiresource):
-        super(Profile, self).__init__(apiresource)
-
 
 class Router(NeutronAPIDictWrapper):
     """Wrapper for neutron routers."""
 
-    def __init__(self, apiresource):
-        _init_apiresource(apiresource)
-        super(Router, self).__init__(apiresource)
-
 
 class RouterStaticRoute(NeutronAPIDictWrapper):
     """Wrapper for neutron routes extra route."""
@@ -317,7 +298,10 @@ class SecurityGroupManager(network_base.SecurityGroupManager):
                  'port_range_max': to_port,
                  'remote_ip_prefix': cidr,
                  'remote_group_id': group_id}}
-        rule = self.client.create_security_group_rule(body)
+        try:
+            rule = self.client.create_security_group_rule(body)
+        except neutron_exc.Conflict:
+            raise exceptions.Conflict(_('Security group rule already exists.'))
         rule = rule.get('security_group_rule')
         sg_dict = self._sg_name_dict(parent_group_id, [rule])
         return SecurityGroupRule(rule, sg_dict)
@@ -605,7 +589,7 @@ def list_resources_with_long_filters(list_method,
 
         val_maxlen = max(len(val) for val in filter_values)
         filter_maxlen = len(filter_attr) + val_maxlen + 2
-        chunk_size = allowed_filter_len / filter_maxlen
+        chunk_size = allowed_filter_len // filter_maxlen
 
         resources = []
         for i in range(0, len(filter_values), chunk_size):
@@ -629,7 +613,8 @@ def network_list(request, **params):
     return [Network(n) for n in networks]
 
 
-def network_list_for_tenant(request, tenant_id, **params):
+def network_list_for_tenant(request, tenant_id, include_external=False,
+                            **params):
     """Return a network list available for the tenant.
 
     The list contains networks owned by the tenant and public networks.
@@ -648,6 +633,11 @@ def network_list_for_tenant(request, tenant_id, **params):
     # both owner networks and public networks in a single API call.
     networks += network_list(request, shared=True, **params)
 
+    if include_external:
+        fetched_net_ids = [n.id for n in networks]
+        ext_nets = network_list(request, **{'router:external': True})
+        networks += [n for n in ext_nets if n.id not in fetched_net_ids]
+
     return networks
 
 
@@ -655,13 +645,13 @@ def network_get(request, network_id, expand_subnet=True, **params):
     LOG.debug("network_get(): netid=%s, params=%s" % (network_id, params))
     network = neutronclient(request).show_network(network_id,
                                                   **params).get('network')
-    # Since the number of subnets per network must be small,
-    # call subnet_get() for each subnet instead of calling
-    # subnet_list() once.
     if expand_subnet:
-        network['subnets'] = [subnet_get(request, sid)
-                              for sid in network['subnets']]
-
+        if request.user.tenant_id == network['tenant_id'] or network['shared']:
+            # Since the number of subnets per network must be small,
+            # call subnet_get() for each subnet instead of calling
+            # subnet_list() once.
+            network['subnets'] = [subnet_get(request, sid)
+                                  for sid in network['subnets']]
     return Network(network)
 
 
@@ -1111,7 +1101,7 @@ def servers_update_addresses(request, servers, all_tenants=False):
                 ports_floating_ips,
                 network_names)
         except Exception as e:
-            LOG.error(e)
+            LOG.error(six.text_type(e))
         else:
             server.addresses = addresses
 
