@@ -63,7 +63,6 @@ class SystemInfoViewTests(test.BaseAdminViewTests):
         self.assertQuerysetEqual(
             services_tab._tables['services'].data,
             ['<Service: compute>',
-             '<Service: volume>',
              '<Service: volumev2>',
              '<Service: image>',
              '<Service: identity (native backend)>',
@@ -72,8 +71,7 @@ class SystemInfoViewTests(test.BaseAdminViewTests):
              '<Service: ec2>',
              '<Service: metering>',
              '<Service: orchestration>',
-             '<Service: database>',
-             '<Service: data-processing>', ])
+             ])
 
         self.mox.VerifyAll()
 
