@@ -24,6 +24,7 @@ from horizon.utils import memoized
 
 from openstack_dashboard import api
 from openstack_dashboard.dashboards.project.networks import views as user_views
+from openstack_dashboard.utils import filters
 
 from openstack_dashboard.dashboards.admin.networks.agents \
     import tables as agents_tables
@@ -105,7 +106,7 @@ class DetailView(tables.MultiTableView):
                      ports_tables.PortsTable,
                      agents_tables.DHCPAgentsTable)
     template_name = 'project/networks/detail.html'
-    page_title = _("Network Details: {{ network.name }}")
+    page_title = '{{ network.name | default:network.id }}'
 
     def get_subnets_data(self):
         try:
@@ -169,21 +170,12 @@ class DetailView(tables.MultiTableView):
         context["network"] = network
         context["url"] = self.get_redirect_url()
         context["actions"] = table.render_row_actions(network)
-        status_label = [label for (value, label) in
-                        networks_tables.project_tables.STATUS_DISPLAY_CHOICES
-                        if value.lower() == (network.status or '').lower()]
-        if status_label:
-            network.status_label = status_label[0]
-        else:
-            network.status_label = network.status
-        admin_state_label = [state for (value, state) in
-                             networks_tables.DISPLAY_CHOICES
-                             if value.lower() ==
-                             (network.admin_state or '').lower()]
-        if admin_state_label:
-            network.admin_state_label = admin_state_label[0]
-        else:
-            network.admin_state_label = network.admin_state
+        choices = networks_tables.project_tables.STATUS_DISPLAY_CHOICES
+        network.status_label = (
+            filters.get_display_label(choices, network.status))
+        choices = networks_tables.DISPLAY_CHOICES
+        network.admin_state_label = (
+            filters.get_display_label(choices, network.admin_state))
         return context
 
     @staticmethod
