@@ -18,4 +18,6 @@ import horizon
 class Volumes(horizon.Panel):
     name = _("Volumes")
     slug = "volumes"
-    permissions = ('openstack.services.volume',)
+    permissions = (
+        ('openstack.services.volume', 'openstack.services.volumev2'),
+    )
