@@ -16,23 +16,22 @@ import copy
 import datetime
 import logging
 import os
+import unittest
 
-import django
 from django.core.urlresolvers import reverse
 from django import http
 from django.test.utils import override_settings
 from django.utils import timezone
-from django.utils import unittest
 
 from mox3.mox import IgnoreArg  # noqa
 from mox3.mox import IsA  # noqa
 
 from horizon import exceptions
 from horizon.workflows import views
+from openstack_auth import policy as policy_backend
 
 from openstack_dashboard import api
 from openstack_dashboard.dashboards.identity.projects import workflows
-from openstack_dashboard import policy_backend
 from openstack_dashboard.test import helpers as test
 from openstack_dashboard import usage
 from openstack_dashboard.usage import quotas
@@ -52,31 +51,43 @@ PROJECT_DETAIL_URL = reverse('horizon:identity:projects:detail', args=[1])
 
 
 class TenantsViewTests(test.BaseAdminViewTests):
-    @test.create_stubs({api.keystone: ('tenant_list',)})
+    @test.create_stubs({api.keystone: ('tenant_list', 'domain_lookup')})
     def test_index(self):
+        domain = self.domains.get(id="1")
         api.keystone.tenant_list(IsA(http.HttpRequest),
                                  domain=None,
                                  paginate=True,
                                  marker=None) \
             .AndReturn([self.tenants.list(), False])
+        api.keystone.domain_lookup(IgnoreArg()).AndReturn({domain.id:
+                                                           domain.name})
         self.mox.ReplayAll()
 
         res = self.client.get(INDEX_URL)
         self.assertTemplateUsed(res, 'identity/projects/index.html')
         self.assertItemsEqual(res.context['table'].data, self.tenants.list())
 
-    @test.create_stubs({api.keystone: ('tenant_list', )})
+    @test.create_stubs({api.keystone: ('tenant_list',
+                                       'get_effective_domain_id',
+                                       'domain_lookup')})
     def test_index_with_domain_context(self):
         domain = self.domains.get(id="1")
+
         self.setSessionValues(domain_context=domain.id,
                               domain_context_name=domain.name)
+
         domain_tenants = [tenant for tenant in self.tenants.list()
                           if tenant.domain_id == domain.id]
+
+        api.keystone.get_effective_domain_id(IgnoreArg()).AndReturn(domain.id)
+
         api.keystone.tenant_list(IsA(http.HttpRequest),
                                  domain=domain.id,
                                  paginate=True,
                                  marker=None) \
                     .AndReturn([domain_tenants, False])
+        api.keystone.domain_lookup(IgnoreArg()).AndReturn({domain.id:
+                                                           domain.name})
         self.mox.ReplayAll()
 
         res = self.client.get(INDEX_URL)
@@ -87,14 +98,18 @@ class TenantsViewTests(test.BaseAdminViewTests):
 
 class ProjectsViewNonAdminTests(test.TestCase):
     @override_settings(POLICY_CHECK_FUNCTION=policy_backend.check)
-    @test.create_stubs({api.keystone: ('tenant_list',)})
+    @test.create_stubs({api.keystone: ('tenant_list',
+                                       'domain_lookup')})
     def test_index(self):
+        domain = self.domains.get(id="1")
         api.keystone.tenant_list(IsA(http.HttpRequest),
                                  user=self.user.id,
                                  paginate=True,
                                  marker=None,
                                  admin=False) \
             .AndReturn([self.tenants.list(), False])
+        api.keystone.domain_lookup(IgnoreArg()).AndReturn({domain.id:
+                                                           domain.name})
         self.mox.ReplayAll()
 
         res = self.client.get(INDEX_URL)
@@ -168,6 +183,7 @@ class CreateProjectWorkflowTests(test.BaseAdminViewTests):
                                        'group_list',
                                        'role_list'),
                         api.base: ('is_service_enabled',),
+                        api.cinder: ('is_volume_service_enabled',),
                         api.neutron: ('is_extension_supported',),
                         quotas: ('get_default_quota_data',)})
     def test_add_project_get(self):
@@ -182,7 +198,7 @@ class CreateProjectWorkflowTests(test.BaseAdminViewTests):
         # init
         api.base.is_service_enabled(IsA(http.HttpRequest), 'network') \
             .MultipleTimes().AndReturn(True)
-        api.base.is_service_enabled(IsA(http.HttpRequest), 'volume') \
+        api.cinder.is_volume_service_enabled(IsA(http.HttpRequest)) \
             .MultipleTimes().AndReturn(True)
         api.keystone.get_default_domain(IsA(http.HttpRequest)) \
             .AndReturn(default_domain)
@@ -266,18 +282,11 @@ class CreateProjectWorkflowTests(test.BaseAdminViewTests):
         res = self.client.get(reverse('horizon:identity:projects:create'))
 
         self.assertTemplateUsed(res, views.WorkflowView.template_name)
-        if django.VERSION >= (1, 6):
-            self.assertContains(res, '''
-                                <input class="form-control"
-                                id="id_subnet" min="-1"
-                                name="subnet" type="number" value="10" />
-                                ''', html=True)
-        else:
-            self.assertContains(res, '''
-                                <input class="form-control"
-                                name="subnet" id="id_subnet"
-                                value="10" type="text" />
-                                ''', html=True)
+        self.assertContains(res, '''
+                            <input class="form-control"
+                            id="id_subnet" min="-1"
+                            name="subnet" type="number" value="10" />
+                            ''', html=True)
 
         workflow = res.context['workflow']
         self.assertEqual(res.context['workflow'].name,
@@ -400,6 +409,7 @@ class CreateProjectWorkflowTests(test.BaseAdminViewTests):
                                        'role_list',
                                        'group_list',
                                        'get_default_domain',
+                                       'is_cloud_admin',
                                        'get_default_role'),
                         quotas: ('get_default_quota_data',
                                  'get_disabled_quotas')})
@@ -414,8 +424,13 @@ class CreateProjectWorkflowTests(test.BaseAdminViewTests):
         # init
         api.keystone.get_default_domain(IsA(http.HttpRequest)) \
             .AndReturn(default_domain)
+
+        api.keystone.is_cloud_admin(IsA(http.HttpRequest)) \
+            .MultipleTimes().AndReturn(True)
+
         quotas.get_disabled_quotas(IsA(http.HttpRequest)) \
             .AndReturn(self.disabled_quotas.first())
+
         quotas.get_default_quota_data(IsA(http.HttpRequest)) \
             .AndRaise(self.exceptions.nova)
 
@@ -463,7 +478,7 @@ class CreateProjectWorkflowTests(test.BaseAdminViewTests):
 
         # init
         api.keystone.get_default_domain(IsA(http.HttpRequest)) \
-            .AndReturn(default_domain)
+            .MultipleTimes().AndReturn(default_domain)
         quotas.get_disabled_quotas(IsA(http.HttpRequest)) \
             .AndReturn(self.disabled_quotas.first())
         quotas.get_default_quota_data(IsA(http.HttpRequest)).AndReturn(quota)
@@ -522,7 +537,7 @@ class CreateProjectWorkflowTests(test.BaseAdminViewTests):
 
         # init
         api.keystone.get_default_domain(IsA(http.HttpRequest)) \
-            .AndReturn(default_domain)
+            .MultipleTimes().AndReturn(default_domain)
         quotas.get_disabled_quotas(IsA(http.HttpRequest)) \
             .AndReturn(self.disabled_quotas.first())
         quotas.get_default_quota_data(IsA(http.HttpRequest)).AndReturn(quota)
@@ -607,8 +622,8 @@ class CreateProjectWorkflowTests(test.BaseAdminViewTests):
         roles = self.roles.list()
 
         # init
-        api.keystone.get_default_domain(IsA(http.HttpRequest)) \
-            .AndReturn(default_domain)
+        api.keystone.get_default_domain(
+            IsA(http.HttpRequest)).MultipleTimes().AndReturn(default_domain)
         quotas.get_disabled_quotas(IsA(http.HttpRequest)) \
             .AndReturn(self.disabled_quotas.first())
         quotas.get_default_quota_data(IsA(http.HttpRequest)).AndReturn(quota)
@@ -779,7 +794,7 @@ class UpdateProjectWorkflowTests(test.BaseAdminViewTests):
             workflow_data[GROUP_ROLE_PREFIX + "2"] = ['1', '2', '3']
             api.keystone.role_assignments_list(IsA(http.HttpRequest),
                                                project=self.tenant.id) \
-               .AndReturn(role_assignments)
+               .MultipleTimes().AndReturn(role_assignments)
             # Give user 1 role 2
             api.keystone.add_tenant_user_role(IsA(http.HttpRequest),
                                               project=self.tenant.id,
@@ -886,7 +901,7 @@ class UpdateProjectWorkflowTests(test.BaseAdminViewTests):
         if keystone_api_version >= 3:
             api.keystone.role_assignments_list(IsA(http.HttpRequest),
                                                project=self.tenant.id) \
-               .AndReturn(role_assignments)
+               .MultipleTimes().AndReturn(role_assignments)
         else:
             api.keystone.user_list(IsA(http.HttpRequest),
                                    project=self.tenant.id) \
@@ -897,10 +912,6 @@ class UpdateProjectWorkflowTests(test.BaseAdminViewTests):
                                             user.id,
                                             self.tenant.id).AndReturn(roles)
 
-        api.keystone.role_assignments_list(IsA(http.HttpRequest),
-                                           project=self.tenant.id) \
-           .AndReturn(role_assignments)
-
         self.mox.ReplayAll()
 
         url = reverse('horizon:identity:projects:update',
@@ -929,6 +940,7 @@ class UpdateProjectWorkflowTests(test.BaseAdminViewTests):
 
     @test.create_stubs({api.keystone: ('tenant_get',
                                        'domain_get',
+                                       'get_effective_domain_id',
                                        'tenant_update',
                                        'get_default_role',
                                        'roles_for_user',
@@ -945,7 +957,7 @@ class UpdateProjectWorkflowTests(test.BaseAdminViewTests):
                         api.cinder: ('tenant_quota_update',),
                         quotas: ('get_tenant_quota_data',
                                  'get_disabled_quotas',
-                                 'tenant_quota_usages')})
+                                 'tenant_quota_usages',)})
     def test_update_project_save(self, neutron=False):
         keystone_api_version = api.keystone.VERSIONS.active
 
@@ -986,11 +998,7 @@ class UpdateProjectWorkflowTests(test.BaseAdminViewTests):
 
         workflow_data = {}
 
-        if keystone_api_version >= 3:
-            api.keystone.role_assignments_list(IsA(http.HttpRequest),
-                                               project=self.tenant.id) \
-               .AndReturn(role_assignments)
-        else:
+        if keystone_api_version < 3:
             api.keystone.user_list(IsA(http.HttpRequest),
                                    project=self.tenant.id) \
                .AndReturn(proj_users)
@@ -1000,10 +1008,6 @@ class UpdateProjectWorkflowTests(test.BaseAdminViewTests):
                                             user.id,
                                             self.tenant.id).AndReturn(roles)
 
-        api.keystone.role_assignments_list(IsA(http.HttpRequest),
-                                           project=self.tenant.id) \
-           .AndReturn(role_assignments)
-
         workflow_data[USER_ROLE_PREFIX + "1"] = ['3']  # admin role
         workflow_data[USER_ROLE_PREFIX + "2"] = ['2']  # member role
         # Group assignment form  data
@@ -1017,16 +1021,22 @@ class UpdateProjectWorkflowTests(test.BaseAdminViewTests):
         quota.metadata_items = 444
         quota.volumes = 444
 
-        updated_project = {"name": project._info["name"],
-                           "description": project._info["description"],
-                           "enabled": project.enabled}
         updated_quota = self._get_quota_info(quota)
 
+        # called once for tenant_update
+        api.keystone.get_effective_domain_id(
+            IsA(http.HttpRequest)).MultipleTimes().AndReturn(domain_id)
+
         # handle
         api.keystone.tenant_update(IsA(http.HttpRequest),
                                    project.id,
-                                   **updated_project) \
-            .AndReturn(project)
+                                   name=project._info["name"],
+                                   description=project._info['description'],
+                                   enabled=project.enabled,
+                                   domain=domain_id).AndReturn(project)
+
+        api.keystone.user_list(IsA(http.HttpRequest),
+                               domain=domain_id).AndReturn(users)
 
         self._check_role_list(keystone_api_version, role_assignments, groups,
                               proj_users, roles, workflow_data)
@@ -1099,6 +1109,7 @@ class UpdateProjectWorkflowTests(test.BaseAdminViewTests):
 
     @test.create_stubs({api.keystone: ('tenant_get',
                                        'domain_get',
+                                       'get_effective_domain_id',
                                        'tenant_update',
                                        'get_default_role',
                                        'roles_for_user',
@@ -1155,7 +1166,7 @@ class UpdateProjectWorkflowTests(test.BaseAdminViewTests):
         if keystone_api_version >= 3:
             api.keystone.role_assignments_list(IsA(http.HttpRequest),
                                                project=self.tenant.id) \
-               .AndReturn(role_assignments)
+                .MultipleTimes().AndReturn(role_assignments)
         else:
             api.keystone.user_list(IsA(http.HttpRequest),
                                    project=self.tenant.id) \
@@ -1171,10 +1182,6 @@ class UpdateProjectWorkflowTests(test.BaseAdminViewTests):
                 workflow_data.setdefault(USER_ROLE_PREFIX + role_ids[0], []) \
                              .append(user.id)
 
-        api.keystone.role_assignments_list(IsA(http.HttpRequest),
-                                           project=self.tenant.id) \
-           .AndReturn(role_assignments)
-
         role_ids = [role.id for role in roles]
         for group in groups:
             if role_ids:
@@ -1188,17 +1195,21 @@ class UpdateProjectWorkflowTests(test.BaseAdminViewTests):
         quota.metadata_items = 444
         quota.volumes = 444
 
-        updated_project = {"name": project._info["name"],
-                           "description": project._info["description"],
-                           "enabled": project.enabled}
         updated_quota = self._get_quota_info(quota)
 
         # handle
         quotas.tenant_quota_usages(IsA(http.HttpRequest), tenant_id=project.id) \
             .AndReturn(quota_usages)
+
+        api.keystone.get_effective_domain_id(
+            IsA(http.HttpRequest)).MultipleTimes().AndReturn(domain_id)
+
         api.keystone.tenant_update(IsA(http.HttpRequest),
                                    project.id,
-                                   **updated_project) \
+                                   name=project._info["name"],
+                                   domain=domain_id,
+                                   description=project._info['description'],
+                                   enabled=project.enabled) \
             .AndRaise(self.exceptions.keystone)
 
         self.mox.ReplayAll()
@@ -1220,6 +1231,7 @@ class UpdateProjectWorkflowTests(test.BaseAdminViewTests):
 
     @test.create_stubs({api.keystone: ('tenant_get',
                                        'domain_get',
+                                       'get_effective_domain_id',
                                        'tenant_update',
                                        'get_default_role',
                                        'roles_for_user',
@@ -1264,8 +1276,10 @@ class UpdateProjectWorkflowTests(test.BaseAdminViewTests):
 
         api.keystone.get_default_role(IsA(http.HttpRequest)) \
             .MultipleTimes().AndReturn(default_role)
-        api.keystone.user_list(IsA(http.HttpRequest), domain=domain_id) \
-            .AndReturn(users)
+
+        api.keystone.user_list(IsA(http.HttpRequest),
+                               domain=domain_id).AndReturn(users)
+
         api.keystone.role_list(IsA(http.HttpRequest)) \
             .MultipleTimes().AndReturn(roles)
         api.keystone.group_list(IsA(http.HttpRequest), domain=domain_id) \
@@ -1273,24 +1287,16 @@ class UpdateProjectWorkflowTests(test.BaseAdminViewTests):
 
         workflow_data = {}
 
-        if keystone_api_version >= 3:
-            api.keystone.role_assignments_list(IsA(http.HttpRequest),
-                                               project=self.tenant.id) \
-               .AndReturn(role_assignments)
-        else:
-            api.keystone.user_list(IsA(http.HttpRequest),
-                                   project=self.tenant.id) \
-               .AndReturn(proj_users)
+        if keystone_api_version < 3:
+            api.keystone.user_list(
+                IsA(http.HttpRequest),
+                project=self.tenant.id).AndReturn(proj_users)
 
             for user in proj_users:
                 api.keystone.roles_for_user(IsA(http.HttpRequest),
                                             user.id,
                                             self.tenant.id).AndReturn(roles)
 
-        api.keystone.role_assignments_list(IsA(http.HttpRequest),
-                                           project=self.tenant.id) \
-           .AndReturn(role_assignments)
-
         workflow_data[USER_ROLE_PREFIX + "1"] = ['1', '3']  # admin role
         workflow_data[USER_ROLE_PREFIX + "2"] = ['1', '2', '3']  # member role
         # Group role assignment data
@@ -1304,16 +1310,21 @@ class UpdateProjectWorkflowTests(test.BaseAdminViewTests):
         quota[0].limit = 444
         quota[1].limit = -1
 
-        updated_project = {"name": project._info["name"],
-                           "description": project._info["description"],
-                           "enabled": project.enabled}
         updated_quota = self._get_quota_info(quota)
 
         # handle
+        api.keystone.get_effective_domain_id(
+            IsA(http.HttpRequest)).MultipleTimes().AndReturn(domain_id)
+
         api.keystone.tenant_update(IsA(http.HttpRequest),
                                    project.id,
-                                   **updated_project) \
-            .AndReturn(project)
+                                   name=project._info["name"],
+                                   description=project._info['description'],
+                                   enabled=project.enabled,
+                                   domain=domain_id).AndReturn(project)
+
+        api.keystone.user_list(IsA(http.HttpRequest),
+                               domain=domain_id).AndReturn(users)
 
         self._check_role_list(keystone_api_version, role_assignments, groups,
                               proj_users, roles, workflow_data)
@@ -1359,7 +1370,8 @@ class UpdateProjectWorkflowTests(test.BaseAdminViewTests):
                                        'add_group_role',
                                        'group_list',
                                        'role_list',
-                                       'role_assignments_list'),
+                                       'role_assignments_list',
+                                       'get_effective_domain_id'),
                         quotas: ('get_tenant_quota_data',
                                  'get_disabled_quotas',
                                  'tenant_quota_usages')})
@@ -1391,8 +1403,10 @@ class UpdateProjectWorkflowTests(test.BaseAdminViewTests):
 
         api.keystone.get_default_role(IsA(http.HttpRequest)) \
             .MultipleTimes().AndReturn(default_role)
+
         api.keystone.user_list(IsA(http.HttpRequest), domain=domain_id) \
             .AndReturn(users)
+
         api.keystone.role_list(IsA(http.HttpRequest)) \
             .MultipleTimes().AndReturn(roles)
         api.keystone.group_list(IsA(http.HttpRequest), domain=domain_id) \
@@ -1400,24 +1414,16 @@ class UpdateProjectWorkflowTests(test.BaseAdminViewTests):
 
         workflow_data = {}
 
-        if keystone_api_version >= 3:
-            api.keystone.role_assignments_list(IsA(http.HttpRequest),
-                                               project=self.tenant.id) \
-               .AndReturn(role_assignments)
-        else:
-            api.keystone.user_list(IsA(http.HttpRequest),
-                                   project=self.tenant.id) \
-               .AndReturn(proj_users)
+        if keystone_api_version < 3:
+            api.keystone.user_list(
+                IsA(http.HttpRequest),
+                project=self.tenant.id).AndReturn(proj_users)
 
             for user in proj_users:
                 api.keystone.roles_for_user(IsA(http.HttpRequest),
                                             user.id,
                                             self.tenant.id).AndReturn(roles)
 
-        api.keystone.role_assignments_list(IsA(http.HttpRequest),
-                                           project=self.tenant.id) \
-           .AndReturn(role_assignments)
-
         workflow_data[USER_ROLE_PREFIX + "1"] = ['1', '3']  # admin role
         workflow_data[USER_ROLE_PREFIX + "2"] = ['1', '2', '3']  # member role
 
@@ -1430,21 +1436,28 @@ class UpdateProjectWorkflowTests(test.BaseAdminViewTests):
         quota.metadata_items = 444
         quota.volumes = 444
 
-        updated_project = {"name": project._info["name"],
-                           "description": project._info["description"],
-                           "enabled": project.enabled}
         updated_quota = self._get_quota_info(quota)
 
         # handle
         quotas.tenant_quota_usages(IsA(http.HttpRequest), tenant_id=project.id) \
             .AndReturn(quota_usages)
+
+        api.keystone.get_effective_domain_id(
+            IsA(http.HttpRequest)).MultipleTimes().AndReturn(domain_id)
+
         api.keystone.tenant_update(IsA(http.HttpRequest),
                                    project.id,
-                                   **updated_project) \
-            .AndReturn(project)
+                                   name=project._info["name"],
+                                   description=project._info['description'],
+                                   enabled=project.enabled,
+                                   domain=domain_id).AndReturn(project)
+
+        api.keystone.user_list(IsA(http.HttpRequest),
+                               domain=domain_id).AndReturn(users)
 
         self._check_role_list(keystone_api_version, role_assignments, groups,
                               proj_users, roles, workflow_data)
+
         self.mox.ReplayAll()
 
         # submit form data
@@ -1463,11 +1476,6 @@ class UpdateProjectWorkflowTests(test.BaseAdminViewTests):
         self.assertMessageCount(error=2, warning=1)
         self.assertRedirectsNoFollow(res, INDEX_URL)
 
-        # django 1.7 and later does not handle the thrown keystoneclient
-        # exception well enough.
-        # TODO(mrunge): re-check when django-1.8 is stable
-        @unittest.skipIf(django.VERSION >= (1, 7, 0),
-                         'Currently skipped with Django >= 1.7')
         @test.create_stubs({api.keystone: ('get_default_role',
                                            'tenant_get',
                                            'domain_get'),
@@ -1566,7 +1574,7 @@ class UsageViewTests(test.BaseAdminViewTests):
         res = self.client.get(csv_url)
         self.assertTemplateUsed(res, 'project/overview/usage.csv')
 
-        self.assertTrue(isinstance(res.context['usage'], usage.ProjectUsage))
+        self.assertIsInstance(res.context['usage'], usage.ProjectUsage)
         hdr = ('Instance Name,VCPUs,RAM (MB),Disk (GB),Usage (Hours),'
                'Time since created (Seconds),State')
         self.assertContains(res, '%s\r\n' % hdr)
@@ -1586,8 +1594,6 @@ class DetailProjectViewTests(test.BaseAdminViewTests):
         self.assertTemplateUsed(res, 'identity/projects/detail.html')
         self.assertEqual(res.context['project'].name, project.name)
         self.assertEqual(res.context['project'].id, project.id)
-        self.assertContains(res, "Project Details: %s" % project.name,
-                            1, 200)
 
     @test.create_stubs({api.keystone: ('tenant_get',)})
     def test_detail_view_with_exception(self):
@@ -1606,7 +1612,8 @@ class DetailProjectViewTests(test.BaseAdminViewTests):
                      "The WITH_SELENIUM env variable is not set.")
 class SeleniumTests(test.SeleniumAdminTestCase):
     @test.create_stubs(
-        {api.keystone: ('tenant_list', 'tenant_get', 'tenant_update')})
+        {api.keystone: ('tenant_list', 'tenant_get', 'tenant_update',
+                        'domain_lookup')})
     def test_inline_editing_update(self):
         # Tenant List
         api.keystone.tenant_list(IgnoreArg(),
@@ -1614,6 +1621,7 @@ class SeleniumTests(test.SeleniumAdminTestCase):
                                  marker=None,
                                  paginate=True) \
             .AndReturn([self.tenants.list(), False])
+        api.keystone.domain_lookup(IgnoreArg()).AndReturn({None: None})
         # Edit mod
         api.keystone.tenant_get(IgnoreArg(),
                                 u'1',
@@ -1687,7 +1695,7 @@ class SeleniumTests(test.SeleniumAdminTestCase):
                         "'Changed test_tenant'")
 
     @test.create_stubs(
-        {api.keystone: ('tenant_list', 'tenant_get')})
+        {api.keystone: ('tenant_list', 'tenant_get', 'domain_lookup')})
     def test_inline_editing_cancel(self):
         # Tenant List
         api.keystone.tenant_list(IgnoreArg(),
@@ -1695,6 +1703,7 @@ class SeleniumTests(test.SeleniumAdminTestCase):
                                  marker=None,
                                  paginate=True) \
             .AndReturn([self.tenants.list(), False])
+        api.keystone.domain_lookup(IgnoreArg()).AndReturn({None: None})
         # Edit mod
         api.keystone.tenant_get(IgnoreArg(),
                                 u'1',
@@ -1745,6 +1754,7 @@ class SeleniumTests(test.SeleniumAdminTestCase):
                                        'group_list',
                                        'role_list'),
                         api.base: ('is_service_enabled',),
+                        api.cinder: ('is_volume_service_enabled',),
                         quotas: ('get_default_quota_data',)})
     def test_membership_list_loads_correctly(self):
         member_css_class = ".available_members"
@@ -1752,7 +1762,7 @@ class SeleniumTests(test.SeleniumAdminTestCase):
 
         api.base.is_service_enabled(IsA(http.HttpRequest), 'network') \
             .MultipleTimes().AndReturn(False)
-        api.base.is_service_enabled(IsA(http.HttpRequest), 'volume') \
+        api.cinder.is_volume_service_enabled(IsA(http.HttpRequest)) \
             .MultipleTimes().AndReturn(False)
         api.keystone.get_default_domain(IsA(http.HttpRequest)) \
             .AndReturn(self.domain)
@@ -1780,3 +1790,9 @@ class SeleniumTests(test.SeleniumAdminTestCase):
 
         for user in users:
             self.assertIn(user.name, members.text)
+
+    @override_settings(OPENSTACK_KEYSTONE_ADMIN_ROLES=['foO', 'BAR', 'admin'])
+    def test_get_admin_roles(self):
+        mix_in = workflows.IdentityMixIn()
+        admin_roles = mix_in.get_admin_roles()
+        self.assertEqual(['foo', 'bar', 'admin'], admin_roles)
