@@ -24,6 +24,9 @@ from openstack_dashboard.usage import quotas
 
 class DeleteKeyPairs(tables.DeleteAction):
     policy_rules = (("compute", "compute_extension:keypairs:delete"),)
+    help_text = _("Removing a key pair can leave OpenStack resources orphaned."
+                  " You should not remove a key pair unless you are certain it"
+                  " is not being used anywhere.")
 
     @staticmethod
     def action_present(count):
