@@ -216,7 +216,8 @@ class AddRule(forms.SelfHandlingForm):
                          required=False,
                          initial="0.0.0.0/0",
                          help_text=_("Classless Inter-Domain Routing "
-                                     "(e.g. 192.168.0.0/24)"),
+                                     "(e.g. 192.168.0.0/24, or "
+                                     "2001:db8::/128)"),
                          version=forms.IPv4 | forms.IPv6,
                          mask=True,
                          widget=forms.TextInput(
@@ -389,6 +390,8 @@ class AddRule(forms.SelfHandlingForm):
         return cleaned_data
 
     def handle(self, request, data):
+        redirect = reverse("horizon:project:access_and_security:"
+                           "security_groups:detail", args=[data['id']])
         try:
             rule = api.network.security_group_rule_create(
                 request,
@@ -404,9 +407,9 @@ class AddRule(forms.SelfHandlingForm):
                              _('Successfully added rule: %s')
                              % six.text_type(rule))
             return rule
+        except exceptions.Conflict as error:
+            exceptions.handle(request, error, redirect=redirect)
         except Exception:
-            redirect = reverse("horizon:project:access_and_security:"
-                               "security_groups:detail", args=[data['id']])
             exceptions.handle(request,
                               _('Unable to add rule to security group.'),
                               redirect=redirect)
