@@ -22,6 +22,7 @@ Views for managing instances.
 from collections import OrderedDict
 import logging
 
+from django.conf import settings
 from django.core.urlresolvers import reverse
 from django.core.urlresolvers import reverse_lazy
 from django import http
@@ -38,6 +39,7 @@ from horizon.utils import memoized
 from horizon import workflows
 
 from openstack_dashboard import api
+from openstack_dashboard.utils import filters
 
 from openstack_dashboard.dashboards.project.instances \
     import console as project_console
@@ -146,6 +148,8 @@ class LaunchInstanceView(workflows.WorkflowView):
         initial = super(LaunchInstanceView, self).get_initial()
         initial['project_id'] = self.request.user.tenant_id
         initial['user_id'] = self.request.user.id
+        defaults = getattr(settings, 'LAUNCH_INSTANCE_DEFAULTS', {})
+        initial['config_drive'] = defaults.get('config_drive', False)
         return initial
 
 
@@ -259,6 +263,7 @@ class RebuildView(forms.ModalFormView):
     template_name = 'project/instances/rebuild.html'
     success_url = reverse_lazy('horizon:project:instances:index')
     page_title = _("Rebuild Instance")
+    submit_label = page_title
 
     def get_context_data(self, **kwargs):
         context = super(RebuildView, self).get_context_data(**kwargs)
@@ -289,9 +294,9 @@ class DecryptPasswordView(forms.ModalFormView):
 
 class DetailView(tabs.TabView):
     tab_group_class = project_tabs.InstanceDetailTabs
-    template_name = 'project/instances/detail.html'
+    template_name = 'horizon/common/_detail.html'
     redirect_url = 'horizon:project:instances:index'
-    page_title = _("Instance Details: {{ instance.name }}")
+    page_title = "{{ instance.name|default:instance.id }}"
     image_url = 'horizon:project:images:images:detail'
     volume_url = 'horizon:project:volumes:volumes:detail'
 
@@ -327,13 +332,9 @@ class DetailView(tabs.TabView):
             # Need to raise here just in case.
             raise exceptions.Http302(redirect)
 
-        status_label = [label for (value, label) in
-                        project_tables.STATUS_DISPLAY_CHOICES
-                        if value.lower() == (instance.status or '').lower()]
-        if status_label:
-            instance.status_label = status_label[0]
-        else:
-            instance.status_label = instance.status
+        choices = project_tables.STATUS_DISPLAY_CHOICES
+        instance.status_label = (
+            filters.get_display_label(choices, instance.status))
 
         try:
             instance.volumes = api.nova.instance_volumes_list(self.request,
