@@ -12,13 +12,12 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import json
-
 from django.core.urlresolvers import reverse
 from django import http
 import django.test
 
 from mox3.mox import IsA  # noqa
+from oslo_serialization import jsonutils
 
 from openstack_dashboard import api
 from openstack_dashboard.dashboards.project.network_topology.views import \
@@ -79,7 +78,7 @@ class NetworkTopologyTests(test.TestCase):
 
         res = self.client.get(JSON_URL)
         self.assertEqual('text/json', res['Content-Type'])
-        data = json.loads(res.content)
+        data = jsonutils.loads(res.content)
 
         # servers
         # result_server_urls = [(server['id'], server['url'])
@@ -94,7 +93,7 @@ class NetworkTopologyTests(test.TestCase):
             for server in self.servers.list()]
         self.assertEqual(expect_server_urls, data['servers'])
 
-        # rotuers
+        # routers
         # result_router_urls = [(router['id'], router['url'])
         #                       for router in data['routers']]
         if router_enable:
@@ -211,6 +210,7 @@ class NetworkTopologyCreateTests(test.TestCase):
         self._test_new_button_disabled_when_quota_exceeded(
             expected_string, routers_quota=0)
 
+    @test.update_settings(LAUNCH_INSTANCE_LEGACY_ENABLED=True)
     @test.create_stubs({quotas: ('tenant_quota_usages',)})
     def test_launch_instance_button_disabled_when_quota_exceeded(self):
         url = reverse('horizon:project:network_topology:launchinstance')
