@@ -17,6 +17,7 @@
 #    under the License.
 
 import json
+import six
 
 from django.conf import settings
 from django.core.urlresolvers import reverse
@@ -26,6 +27,7 @@ from django.utils.translation import ugettext_lazy as _
 from django.views.generic import View  # noqa
 
 from horizon import exceptions
+from horizon.utils.lazy_encoder import LazyTranslationEncoder
 from horizon import views
 
 from openstack_dashboard import api
@@ -44,6 +46,8 @@ from openstack_dashboard.dashboards.project.network_topology.subnets \
 
 from openstack_dashboard.dashboards.project.instances import\
     console as i_console
+from openstack_dashboard.dashboards.project.instances.tables import \
+    STATUS_DISPLAY_CHOICES as instance_choices
 from openstack_dashboard.dashboards.project.instances import\
     views as i_views
 from openstack_dashboard.dashboards.project.instances.workflows import\
@@ -52,16 +56,48 @@ from openstack_dashboard.dashboards.project.networks.subnets import\
     views as s_views
 from openstack_dashboard.dashboards.project.networks.subnets import\
     workflows as s_workflows
+from openstack_dashboard.dashboards.project.networks.tables import \
+    DISPLAY_CHOICES as network_display_choices
+from openstack_dashboard.dashboards.project.networks.tables import \
+    STATUS_DISPLAY_CHOICES as network_choices
 from openstack_dashboard.dashboards.project.networks import\
     views as n_views
 from openstack_dashboard.dashboards.project.networks import\
     workflows as n_workflows
+from openstack_dashboard.dashboards.project.routers.ports.tables import \
+    DISPLAY_CHOICES as ports_choices
+from openstack_dashboard.dashboards.project.routers.ports.tables import \
+    STATUS_DISPLAY_CHOICES as ports_status_choices
 from openstack_dashboard.dashboards.project.routers.ports import\
     views as p_views
+from openstack_dashboard.dashboards.project.routers.tables import \
+    ADMIN_STATE_DISPLAY_CHOICES as routers_admin_choices
+from openstack_dashboard.dashboards.project.routers.tables import \
+    STATUS_DISPLAY_CHOICES as routers_status_choices
 from openstack_dashboard.dashboards.project.routers import\
     views as r_views
 
 
+class TranslationHelper(object):
+    """Helper class to provide the translations of instances, networks,
+    routers and ports from other parts of the code to the network topology
+    """
+    def __init__(self):
+        # turn translation tuples into dicts for easy access
+        self.instance = dict(instance_choices)
+        self.network = dict(network_choices)
+        self.network.update(dict(network_display_choices))
+        self.router = dict(routers_admin_choices)
+        self.router.update(dict(routers_status_choices))
+        self.port = dict(ports_choices)
+        self.port.update(dict(ports_status_choices))
+        # and turn all the keys into Uppercase for simple access
+        self.instance = {k.upper(): v for k, v in six.iteritems(self.instance)}
+        self.network = {k.upper(): v for k, v in six.iteritems(self.network)}
+        self.router = {k.upper(): v for k, v in six.iteritems(self.router)}
+        self.port = {k.upper(): v for k, v in six.iteritems(self.port)}
+
+
 class NTAddInterfaceView(p_views.AddInterfaceView):
     success_url = "horizon:project:network_topology:index"
     failure_url = "horizon:project:network_topology:index"
@@ -176,13 +212,14 @@ class NetworkTopologyView(views.HorizonTemplateView):
         context['console_type'] = getattr(
             settings, 'CONSOLE_TYPE', 'AUTO')
         context['show_ng_launch'] = getattr(
-            settings, 'LAUNCH_INSTANCE_NG_ENABLED', False)
+            settings, 'LAUNCH_INSTANCE_NG_ENABLED', True)
         context['show_legacy_launch'] = getattr(
-            settings, 'LAUNCH_INSTANCE_LEGACY_ENABLED', True)
+            settings, 'LAUNCH_INSTANCE_LEGACY_ENABLED', False)
         return context
 
 
 class JSONView(View):
+    trans = TranslationHelper()
 
     @property
     def is_router_enabled(self):
@@ -221,7 +258,8 @@ class JSONView(View):
                 console = None
 
             server_data = {'name': server.name,
-                           'status': server.status,
+                           'status': self.trans.instance[server.status],
+                           'original_status': server.status,
                            'task': getattr(server, 'OS-EXT-STS:task_state'),
                            'id': server.id}
             if console:
@@ -249,7 +287,8 @@ class JSONView(View):
                    'subnets': [{'id': subnet.id,
                                 'cidr': subnet.cidr}
                                for subnet in network.subnets],
-                   'status': network.status,
+                   'status': self.trans.network[network.status],
+                   'original_status': network.status,
                    'router:external': network['router:external']}
             self.add_resource_url('horizon:project:networks:subnets:detail',
                                   obj['subnets'])
@@ -281,7 +320,8 @@ class JSONView(View):
                     'name': publicnet.name_or_id,
                     'id': publicnet.id,
                     'subnets': subnets,
-                    'status': publicnet.status,
+                    'status': self.trans.network[publicnet.status],
+                    'original_status': publicnet.status,
                     'router:external': publicnet['router:external']})
 
         self.add_resource_url('horizon:project:networks:detail',
@@ -303,7 +343,8 @@ class JSONView(View):
 
         routers = [{'id': router.id,
                     'name': router.name_or_id,
-                    'status': router.status,
+                    'status': self.trans.router[router.status],
+                    'original_status': router.status,
                     'external_gateway_info': router.external_gateway_info}
                    for router in neutron_routers]
         self.add_resource_url('horizon:project:routers:detail', routers)
@@ -320,7 +361,8 @@ class JSONView(View):
                   'device_id': port.device_id,
                   'fixed_ips': port.fixed_ips,
                   'device_owner': port.device_owner,
-                  'status': port.status}
+                  'status': self.trans.port[port.status],
+                  'original_status': port.status}
                  for port in neutron_ports
                  if port.device_owner != 'network:router_ha_interface']
         self.add_resource_url('horizon:project:networks:ports:detail',
@@ -354,5 +396,6 @@ class JSONView(View):
                 'ports': self._get_ports(request),
                 'routers': self._get_routers(request)}
         self._prepare_gateway_ports(data['routers'], data['ports'])
-        json_string = json.dumps(data, ensure_ascii=False)
+        json_string = json.dumps(data, cls=LazyTranslationEncoder,
+                                 ensure_ascii=False)
         return HttpResponse(json_string, content_type='text/json')
