@@ -30,7 +30,10 @@ from horizon import messages
 from horizon import tables
 from horizon import tabs
 from horizon.utils import memoized
+
 from openstack_dashboard import api
+from openstack_dashboard.utils import filters
+
 from openstack_dashboard.dashboards.project.routers\
     import forms as project_forms
 from openstack_dashboard.dashboards.project.routers import tables as rtables
@@ -90,17 +93,18 @@ class IndexView(tables.DataTableView):
                 messages.error(self.request, msg)
                 # gateway_info['network'] is just the network name, so putting
                 # in a smallish error message in the table is reasonable.
+                # Translators: The usage is "<UUID of ext_net> (Not Found)"
                 gateway_info['network'] = pgettext_lazy(
                     'External network not found',
-                    # Translators: The usage is "<UUID of ext_net> (Not Found)"
                     u'%s (Not Found)') % ext_net_id
 
 
 class DetailView(tabs.TabbedTableView):
     tab_group_class = rdtabs.RouterDetailTabs
-    template_name = 'project/routers/detail.html'
+    template_name = 'horizon/common/_detail.html'
     failure_url = reverse_lazy('horizon:project:routers:index')
-    page_title = _("Router Details")
+    network_url = 'horizon:project:networks:detail'
+    page_title = "{{ router.name|default:router.id }}"
 
     @memoized.memoized_method
     def _get_data(self):
@@ -114,6 +118,8 @@ class DetailView(tabs.TabbedTableView):
             exceptions.handle(self.request, msg, redirect=self.failure_url)
         if router.external_gateway_info:
             ext_net_id = router.external_gateway_info['network_id']
+            router.external_gateway_info['network_url'] = reverse(
+                self.network_url, args=[ext_net_id])
             try:
                 ext_net = api.neutron.network_get(self.request, ext_net_id,
                                                   expand_subnet=False)
@@ -149,22 +155,11 @@ class DetailView(tabs.TabbedTableView):
             self.request, "dvr", "get")
         context['ha_supported'] = api.neutron.get_feature_permission(
             self.request, "l3-ha", "get")
-        status_label = [label for (value, label) in
-                        table.STATUS_DISPLAY_CHOICES
-                        if value.lower() == (router.status or '').lower()]
-        if status_label:
-            router.status_label = status_label[0]
-        else:
-            router.status_label = router.status
-        admin_state_label = [state for (value, state) in
-                             table.ADMIN_STATE_DISPLAY_CHOICES
-                             if value.lower() ==
-                             (router.admin_state or '').lower()]
-        if admin_state_label:
-            router.admin_state_label = admin_state_label[0]
-        else:
-            router.admin_state_label = router.admin_state
-
+        choices = rtables.STATUS_DISPLAY_CHOICES
+        router.status_label = filters.get_display_label(choices, router.status)
+        choices = rtables.ADMIN_STATE_DISPLAY_CHOICES
+        router.admin_state_label = (
+            filters.get_display_label(choices, router.admin_state))
         return context
 
     def get_tabs(self, request, *args, **kwargs):
