@@ -35,17 +35,17 @@ def _one_year():
 
 
 class UserSettingsForm(forms.SelfHandlingForm):
+    max_value = getattr(settings, 'API_RESULT_LIMIT', 1000)
     language = forms.ChoiceField(label=_("Language"))
     timezone = forms.ChoiceField(label=_("Timezone"))
     pagesize = forms.IntegerField(label=_("Items Per Page"),
                                   min_value=1,
-                                  max_value=getattr(settings,
-                                                    'API_RESULT_LIMIT',
-                                                    1000),
+                                  max_value=max_value,
                                   help_text=_("Number of items to show per "
                                               "page (applies to the pages "
                                               "that have API supported "
-                                              "pagination)"))
+                                              "pagination, "
+                                              "Max Value: %s)") % max_value)
     instance_log_length = forms.IntegerField(
         label=_("Log Lines Per Instance"), min_value=1,
         help_text=_("Number of log lines to be shown per instance"))
