@@ -21,16 +21,14 @@ import os
 import sys
 import warnings
 
-import django
+from django.utils.translation import pgettext_lazy
 from django.utils.translation import ugettext_lazy as _
 
 from openstack_dashboard import exceptions
 from openstack_dashboard.static_settings import find_static_files  # noqa
 from openstack_dashboard.static_settings import get_staticfiles_dirs  # noqa
+from openstack_dashboard import theme_settings
 
-from horizon.utils.escape import monkeypatch_escape
-
-monkeypatch_escape()
 
 warnings.formatwarning = lambda message, category, *args, **kwargs: \
     '%s: %s' % (category.__name__, message)
@@ -63,6 +61,7 @@ HORIZON_CONFIG = {
         'fade_duration': 1500,
         'types': ['alert-success', 'alert-info']
     },
+    'bug_url': None,
     'help_url': "http://docs.openstack.org",
     'exceptions': {'recoverable': exceptions.RECOVERABLE,
                    'not_found': exceptions.NOT_FOUND,
@@ -72,6 +71,7 @@ HORIZON_CONFIG = {
     'js_files': [],
     'js_spec_files': [],
     'external_templates': [],
+    'plugins': []
 }
 
 # Set to True to allow users to upload images to glance via Horizon server.
@@ -105,14 +105,9 @@ MIDDLEWARE_CLASSES = (
     'django.contrib.sessions.middleware.SessionMiddleware',
     'django.contrib.auth.middleware.AuthenticationMiddleware',
     'django.contrib.messages.middleware.MessageMiddleware',
-)
-if django.VERSION >= (1, 8, 0):
-    MIDDLEWARE_CLASSES += (
-        'django.contrib.auth.middleware.SessionAuthenticationMiddleware',)
-else:
-    MIDDLEWARE_CLASSES += ('django.middleware.doc.XViewMiddleware',)
-MIDDLEWARE_CLASSES += (
+    'django.contrib.auth.middleware.SessionAuthenticationMiddleware',
     'horizon.middleware.HorizonMiddleware',
+    'horizon.themes.ThemeMiddleware',
     'django.middleware.locale.LocaleMiddleware',
     'django.middleware.clickjacking.XFrameOptionsMiddleware',
 )
@@ -129,9 +124,12 @@ TEMPLATE_CONTEXT_PROCESSORS = (
 )
 
 TEMPLATE_LOADERS = (
-    'django.template.loaders.filesystem.Loader',
-    'django.template.loaders.app_directories.Loader',
-    'horizon.loaders.TemplateLoader',
+    'horizon.themes.ThemeTemplateLoader',
+    ('django.template.loaders.cached.Loader', (
+        'django.template.loaders.filesystem.Loader',
+        'django.template.loaders.app_directories.Loader',
+        'horizon.loaders.TemplateLoader',
+    )),
 )
 
 TEMPLATE_DIRS = (
@@ -182,13 +180,11 @@ SESSION_ENGINE = 'django.contrib.sessions.backends.signed_cookies'
 SESSION_COOKIE_HTTPONLY = True
 SESSION_EXPIRE_AT_BROWSER_CLOSE = True
 SESSION_COOKIE_SECURE = False
-SESSION_TIMEOUT = 1800
-# A token can be near the end of validity when a page starts loading, and
-# invalid during the rendering which can cause errors when a page load.
-# TOKEN_TIMEOUT_MARGIN defines a time in seconds we retrieve from token
-# validity to avoid this issue. You can adjust this time depending on the
-# performance of the infrastructure.
-TOKEN_TIMEOUT_MARGIN = 10
+
+# SESSION_TIMEOUT is a method to supersede the token timeout with a shorter
+# horizon session timeout (in seconds).  So if your token expires in 60
+# minutes, a value of 1800 will log users out after 30 minutes
+SESSION_TIMEOUT = 3600
 
 # When using cookie-based sessions, log error when the session cookie exceeds
 # the following size (common browsers drop cookies above a certain size):
@@ -204,6 +200,7 @@ LANGUAGES = (
     ('de', 'German'),
     ('en', 'English'),
     ('en-au', 'Australian English'),
+    ('en-gb', 'British English'),
     ('es', 'Spanish'),
     ('fr', 'French'),
     ('it', 'Italian'),
@@ -264,16 +261,50 @@ SECURITY_GROUP_RULES = {
 
 ADD_INSTALLED_APPS = []
 
-# directory for custom theme, set as default.
-# It can be overridden in local_settings.py
-DEFAULT_THEME_PATH = 'themes/default'
-CUSTOM_THEME_PATH = DEFAULT_THEME_PATH
+# Deprecated Theme Settings
+CUSTOM_THEME_PATH = None
+DEFAULT_THEME_PATH = None
+
+# 'key', 'label', 'path'
+AVAILABLE_THEMES = [
+    (
+        'default',
+        pgettext_lazy('Default style theme', 'Default'),
+        'themes/default'
+    ), (
+        'material',
+        pgettext_lazy("Google's Material Design style theme", "Material"),
+        'themes/material'
+    ),
+]
+
+# The default theme if no cookie is present
+DEFAULT_THEME = 'default'
+
+# Theme Static Directory
+THEME_COLLECTION_DIR = 'themes'
+
+# Theme Cookie Name
+THEME_COOKIE_NAME = 'theme'
 
 try:
     from local.local_settings import *  # noqa
 except ImportError:
     logging.warning("No local_settings file found.")
 
+# allow to drop settings snippets into a local_settings_dir
+LOCAL_SETTINGS_DIR_PATH = os.path.join(ROOT_PATH, "local", "local_settings.d")
+if os.path.exists(LOCAL_SETTINGS_DIR_PATH):
+    for (dirpath, dirnames, filenames) in os.walk(LOCAL_SETTINGS_DIR_PATH):
+        for filename in sorted(filenames):
+            if filename.endswith(".py"):
+                try:
+                    execfile(os.path.join(dirpath, filename))
+                except Exception as e:
+                    logging.exception(
+                        "Can not exec settings snippet %s" % (filename))
+
+
 if not WEBROOT.endswith('/'):
     WEBROOT += '/'
 if LOGIN_URL is None:
@@ -292,44 +323,43 @@ if STATIC_ROOT is None:
 if STATIC_URL is None:
     STATIC_URL = WEBROOT + 'static/'
 
-STATICFILES_DIRS = get_staticfiles_dirs(STATIC_URL)
-
-CUSTOM_THEME = os.path.join(ROOT_PATH, CUSTOM_THEME_PATH)
-
-# If a custom template directory exists within our custom theme, then prepend
-# it to our first-come, first-serve TEMPLATE_DIRS
-if os.path.exists(os.path.join(CUSTOM_THEME, 'templates')):
-    TEMPLATE_DIRS = \
-        (os.path.join(CUSTOM_THEME, 'templates'),) + TEMPLATE_DIRS
-
-# Only expose the subdirectory 'static' if it exists from a custom theme,
-# allowing other logic to live with a theme that we might not want to expose
-# statically
-if os.path.exists(os.path.join(CUSTOM_THEME, 'static')):
-    CUSTOM_THEME = os.path.join(CUSTOM_THEME, 'static')
-
-# Only collect and expose the default theme if the user chose to set a
-# different theme
-if DEFAULT_THEME_PATH != CUSTOM_THEME_PATH:
-    STATICFILES_DIRS.append(
-        ('themes/default', os.path.join(ROOT_PATH, DEFAULT_THEME_PATH)),
-    )
-
-STATICFILES_DIRS.append(
-    ('custom', CUSTOM_THEME),
+AVAILABLE_THEMES, DEFAULT_THEME = theme_settings.get_available_themes(
+    AVAILABLE_THEMES,
+    CUSTOM_THEME_PATH,
+    DEFAULT_THEME_PATH,
+    DEFAULT_THEME
 )
 
-# Load the subdirectory 'img' of a custom theme if it exists, thereby allowing
-# very granular theme overrides of all dashboard img files using the first-come
-# first-serve filesystem loader.
-if os.path.exists(os.path.join(CUSTOM_THEME, 'img')):
-    STATICFILES_DIRS.insert(0, ('dashboard/img',
-                            os.path.join(CUSTOM_THEME, 'img')))
+STATICFILES_DIRS = get_staticfiles_dirs(STATIC_URL) + \
+    theme_settings.get_theme_static_dirs(
+        AVAILABLE_THEMES,
+        THEME_COLLECTION_DIR,
+        ROOT_PATH)
+
+if CUSTOM_THEME_PATH is not None:
+    logging.warning("CUSTOM_THEME_PATH has been deprecated.  Please convert "
+                    "your settings to make use of AVAILABLE_THEMES.")
+
+if DEFAULT_THEME_PATH is not None:
+    logging.warning("DEFAULT_THEME_PATH has been deprecated.  Please convert "
+                    "your settings to make use of AVAILABLE_THEMES.")
 
 # populate HORIZON_CONFIG with auto-discovered JavaScript sources, mock files,
 # specs files and external templates.
 find_static_files(HORIZON_CONFIG)
 
+# Ensure that we always have a SECRET_KEY set, even when no local_settings.py
+# file is present. See local_settings.py.example for full documentation on the
+# horizon.utils.secret_key module and its use.
+if not SECRET_KEY:
+    if not LOCAL_PATH:
+        LOCAL_PATH = os.path.join(os.path.dirname(os.path.abspath(__file__)),
+                                  'local')
+
+    from horizon.utils import secret_key
+    SECRET_KEY = secret_key.generate_or_read_from_file(os.path.join(LOCAL_PATH,
+                                                       '.secret_key_store'))
+
 # Load the pluggable dashboard settings
 import openstack_dashboard.enabled
 import openstack_dashboard.local.enabled
@@ -346,28 +376,19 @@ settings.update_dashboards(
 )
 INSTALLED_APPS[0:0] = ADD_INSTALLED_APPS
 
-# Ensure that we always have a SECRET_KEY set, even when no local_settings.py
-# file is present. See local_settings.py.example for full documentation on the
-# horizon.utils.secret_key module and its use.
-if not SECRET_KEY:
-    if not LOCAL_PATH:
-        LOCAL_PATH = os.path.join(os.path.dirname(os.path.abspath(__file__)),
-                                  'local')
+from openstack_auth import policy
+POLICY_CHECK_FUNCTION = policy.check
 
-    from horizon.utils import secret_key
-    SECRET_KEY = secret_key.generate_or_read_from_file(os.path.join(LOCAL_PATH,
-                                                       '.secret_key_store'))
-
-from openstack_dashboard import policy_backend
-POLICY_CHECK_FUNCTION = policy_backend.check
-
-# Add HORIZON_CONFIG to the context information for offline compression
-COMPRESS_OFFLINE_CONTEXT = {
+# This base context objects gets added to the offline context generator
+# for each theme configured.
+HORIZON_COMPRESS_OFFLINE_CONTEXT_BASE = {
     'WEBROOT': WEBROOT,
     'STATIC_URL': STATIC_URL,
-    'HORIZON_CONFIG': HORIZON_CONFIG,
+    'HORIZON_CONFIG': HORIZON_CONFIG
 }
 
+COMPRESS_OFFLINE_CONTEXT = 'horizon.themes.offline_context'
+
 if DEBUG:
     logging.basicConfig(level=logging.DEBUG)
 
@@ -377,3 +398,5 @@ if DEBUG:
 # below may be omitted, though it should not be harmful
 from openstack_auth import utils as auth_utils
 auth_utils.patch_middleware_get_user()
+
+CSRF_COOKIE_AGE = None
