@@ -23,8 +23,10 @@
    */
   var libraryModules = [
     'gettext',
+    'lrDragNDrop',
     'ngCookies',
     'ngSanitize',
+    'smart-table',
     'ui.bootstrap'
   ];
 
@@ -54,21 +56,48 @@
    * 3) Horizon's plug-in modules.
    */
   angular
-    .module('horizon.app', []
-      .concat(libraryModules)
-      .concat(horizonBuiltInModules)
-      .concat(horizonPlugInModules)
-    )
-
+    .module('horizon.app', ['ngRoute']
+            .concat(libraryModules)
+            .concat(horizonBuiltInModules)
+            .concat(horizonPlugInModules)
+           )
+    .config(configHorizon)
     .run(updateHorizon);
 
+  configHorizon.$inject = [
+    '$locationProvider',
+    '$routeProvider'
+  ];
+
+  /**
+   * Configure the Horizon Angular Application.
+   * This sets up the $locationProvider Service to use HTML5 Mode and
+   * the Hash Prefix to use when it is not supported.
+   *
+   * It also sets the default Angular route which will apply if
+   * a link is clicked that doesn't match any current Angular route.
+   *
+   */
+  function configHorizon($locationProvider, $routeProvider) {
+    if (angular.element('base').length === 1) {
+      $locationProvider.html5Mode(true).hashPrefix('!');
+
+      $routeProvider
+        .otherwise({
+          template: '',
+          controller: 'RedirectController'
+        });
+    }
+  }
+
   updateHorizon.$inject = [
     'gettextCatalog',
     'horizon.framework.conf.spinner_options',
     'horizon.framework.util.tech-debt.helper-functions',
     '$cookieStore',
     '$http',
-    '$cookies'
+    '$cookies',
+    '$route'
   ];
 
   function updateHorizon(
@@ -77,11 +106,13 @@
     hzUtils,
     $cookieStore,
     $http,
-    $cookies) {
+    $cookies,
+    $route
+  ) {
 
     $http.defaults.headers.post['X-CSRFToken'] = $cookies.csrftoken;
 
-    //expose the configuration for horizon legacy variable
+    // expose the legacy utils module
     horizon.utils = hzUtils;
 
     horizon.conf.spinner_options = spinnerOptions;
@@ -95,6 +126,11 @@
     gettextCatalog.setCurrentLanguage(horizon.languageCode);
     gettextCatalog.setStrings(horizon.languageCode, django.catalog);
 
+    // because of angular startup, and our use of ng-include with
+    // embedded ng-view, we need to re-kick ngRoute after everything's
+    // resolved
+    $route.reload();
+
     /*
      * cookies are updated at the end of current $eval, so for the horizon
      * namespace we need to wrap it in a $apply function.
