@@ -18,14 +18,14 @@
 
   angular
     .module('horizon.app.core.openstack-service-api')
-    .factory('horizon.app.core.openstack-service-api.keystone', KeystoneAPI);
+    .factory('horizon.app.core.openstack-service-api.keystone', keystoneAPI);
 
-  KeystoneAPI.$inject = [
+  keystoneAPI.$inject = [
     'horizon.framework.util.http.service',
     'horizon.framework.widgets.toast.service'
   ];
 
-  function KeystoneAPI(apiService, toastService) {
+  function keystoneAPI(apiService, toastService) {
     var service = {
       getVersion: getVersion,
       getUsers: getUsers,
@@ -54,7 +54,8 @@
       editProject: editProject,
       deleteProject: deleteProject,
       grantRole: grantRole,
-      serviceCatalog: serviceCatalog
+      serviceCatalog: serviceCatalog,
+      getServices: getServices
     };
 
     return service;
@@ -71,7 +72,7 @@
 
     // Users
     function getUsers(params) {
-      var config = (params) ? {'params': params} : {};
+      var config = params ? {'params': params} : {};
       return apiService.get('/api/keystone/users/', config)
         .error(function () {
           toastService.add('error', gettext('Unable to retrieve the users.'));
@@ -92,6 +93,13 @@
         });
     }
 
+    function getServices() {
+      return apiService.get('/api/keystone/services/')
+        .error(function () {
+          toastService.add('error', gettext('Unable to fetch the services.'));
+        });
+    }
+
     /**
     * @name horizon.app.core.openstack-service-api.keystone.getCurrentUserSession
     * @description
@@ -239,7 +247,7 @@
 
     // Projects
     function getProjects(params) {
-      var config = (params) ? {'params': params} : {};
+      var config = params ? {'params': params} : {};
       return apiService.get('/api/keystone/projects/', config)
         .error(function () {
           toastService.add('error', gettext('Unable to retrieve the projects.'));
