@@ -25,7 +25,7 @@ class RestUtilsTestCase(test.TestCase):
         response = f(None, request)
         request.user.is_authenticated.assert_called_once_with()
         self.assertStatusCode(response, 200)
-        self.assertEqual(response.content, '"ok"')
+        self.assertEqual(response.json, "ok")
 
     def test_api_success_no_auth_ok(self):
         @utils.ajax(authenticated=False)
@@ -35,7 +35,7 @@ class RestUtilsTestCase(test.TestCase):
         response = f(None, request)
         request.user.is_authenticated.assert_not_called()
         self.assertStatusCode(response, 200)
-        self.assertEqual(response.content, '"ok"')
+        self.assertEqual(response.json, "ok")
 
     def test_api_auth_required(self):
         @utils.ajax()
@@ -47,7 +47,7 @@ class RestUtilsTestCase(test.TestCase):
         response = f(None, request)
         request.user.is_authenticated.assert_called_once_with()
         self.assertStatusCode(response, 401)
-        self.assertEqual(response.content, '"not logged in"')
+        self.assertEqual(response.json, "not logged in")
 
     def test_api_success_204(self):
         @utils.ajax()
@@ -56,7 +56,7 @@ class RestUtilsTestCase(test.TestCase):
         request = self.mock_rest_request()
         response = f(None, request)
         self.assertStatusCode(response, 204)
-        self.assertEqual(response.content, '')
+        self.assertEqual(response.content, b'')
 
     def test_api_error(self):
         @utils.ajax()
@@ -65,7 +65,7 @@ class RestUtilsTestCase(test.TestCase):
         request = self.mock_rest_request()
         response = f(None, request)
         self.assertStatusCode(response, 500)
-        self.assertEqual(response.content, '"b0rk"')
+        self.assertEqual(response.json, "b0rk")
 
     def test_api_malformed_json(self):
         @utils.ajax()
@@ -74,8 +74,7 @@ class RestUtilsTestCase(test.TestCase):
         request = self.mock_rest_request(**{'body': 'spam'})
         response = f(None, request)
         self.assertStatusCode(response, 400)
-        self.assertEqual(response.content, '"malformed JSON request: No JSON '
-                         'object could be decoded"')
+        self.assertIn(b'"malformed JSON request: ', response.content)
 
     def test_api_not_found(self):
         @utils.ajax()
@@ -84,7 +83,7 @@ class RestUtilsTestCase(test.TestCase):
         request = self.mock_rest_request()
         response = f(None, request)
         self.assertStatusCode(response, 404)
-        self.assertEqual(response.content, '"b0rk"')
+        self.assertEqual(response.json, "b0rk")
 
     def test_data_required_with_no_data(self):
         @utils.ajax(data_required=True)
@@ -93,7 +92,7 @@ class RestUtilsTestCase(test.TestCase):
         request = self.mock_rest_request()
         response = f(None, request)
         self.assertStatusCode(response, 400)
-        self.assertEqual(response.content, '"request requires JSON body"')
+        self.assertEqual(response.json, "request requires JSON body")
 
     def test_valid_data_required(self):
         @utils.ajax(data_required=True)
@@ -104,7 +103,7 @@ class RestUtilsTestCase(test.TestCase):
         '''})
         response = f(None, request)
         self.assertStatusCode(response, 200)
-        self.assertEqual(response.content, '"OK"')
+        self.assertEqual(response.json, "OK")
 
     def test_api_created_response(self):
         @utils.ajax()
@@ -115,7 +114,7 @@ class RestUtilsTestCase(test.TestCase):
         request.user.is_authenticated.assert_called_once_with()
         self.assertStatusCode(response, 201)
         self.assertEqual(response['location'], '/api/spam/spam123')
-        self.assertEqual(response.content, '')
+        self.assertEqual(response.content, b'')
 
     def test_api_created_response_content(self):
         @utils.ajax()
@@ -126,7 +125,7 @@ class RestUtilsTestCase(test.TestCase):
         request.user.is_authenticated.assert_called_once_with()
         self.assertStatusCode(response, 201)
         self.assertEqual(response['location'], '/api/spam/spam123')
-        self.assertEqual(response.content, '"spam!"')
+        self.assertEqual(response.json, "spam!")
 
     def test_parse_filters_keywords(self):
         kwargs = {
@@ -189,7 +188,7 @@ class JSONEncoderTestCase(test.TestCase):
         request.user.is_authenticated.assert_called_once_with()
         self.assertStatusCode(response, 200)
         self.assertEqual(response['content-type'], 'application/json')
-        self.assertEqual(response.content, 'NaN')
+        self.assertEqual(response.content, b'NaN')
 
     def test_custom_encoder_on_infinity(self):
         @utils.ajax(json_encoder=json_encoder.NaNJSONEncoder)
@@ -201,7 +200,7 @@ class JSONEncoderTestCase(test.TestCase):
         request.user.is_authenticated.assert_called_once_with()
         self.assertStatusCode(response, 200)
         self.assertEqual(response['content-type'], 'application/json')
-        self.assertEqual(response.content, '1e+999')
+        self.assertEqual(response.content, b'1e+999')
 
     def test_custom_encoder_on_negative_infinity(self):
         @utils.ajax(json_encoder=json_encoder.NaNJSONEncoder)
@@ -213,7 +212,7 @@ class JSONEncoderTestCase(test.TestCase):
         request.user.is_authenticated.assert_called_once_with()
         self.assertStatusCode(response, 200)
         self.assertEqual(response['content-type'], 'application/json')
-        self.assertEqual(response.content, '-1e+999')
+        self.assertEqual(response.content, b'-1e+999')
 
     def test_custom_encoder_yields_standard_json_for_conventional_data(self):
         @utils.ajax()
