@@ -10,7 +10,6 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from selenium.common.exceptions import NoSuchElementException
 from selenium.webdriver.common import by
 
 from openstack_dashboard.test.integration_tests.pages import navigation
@@ -24,8 +23,6 @@ class BasePage(pageobject.PageObject):
     """Base class for all dashboard page objects."""
 
     _heading_locator = (by.By.CSS_SELECTOR, 'div.page-header > h2')
-    _error_msg_locator = (by.By.CSS_SELECTOR, 'div.alert-danger.alert')
-    _spinner_locator = (by.By.CSS_SELECTOR, 'div.modal-backdrop')
 
     @property
     def heading(self):
@@ -43,14 +40,6 @@ class BasePage(pageobject.PageObject):
     def navaccordion(self):
         return menus.NavigationAccordionRegion(self.driver, self.conf)
 
-    @property
-    def error_message(self):
-        src_elem = self._get_element(*self._error_msg_locator)
-        return messages.ErrorMessageRegion(self.driver, self.conf, src_elem)
-
-    def is_error_message_present(self):
-        return self._is_element_present(*self._error_msg_locator)
-
     def go_to_login_page(self):
         self.driver.get(self.login_url)
 
@@ -64,18 +53,11 @@ class BasePage(pageobject.PageObject):
     def go_to_help_page(self):
         self.topbar.user_dropdown_menu.click_on_help()
 
-    def _wait_till_spinner_disappears(self):
-        try:
-            self._turn_off_implicit_wait()
-            spinner = self._get_element(*self._spinner_locator)
-            self._wait_till_element_disappears(spinner)
-        except NoSuchElementException:
-            # NOTE(mpavlase): This is valid state. When request completes
-            # even before Selenium get a chance to get the spinner element,
-            # it will raise the NoSuchElementException exception.
-            pass
-        finally:
-            self._turn_on_implicit_wait()
+    def find_message_and_dismiss(self, message_level=messages.SUCCESS):
+        message = messages.MessageRegion(self.driver, self.conf, message_level)
+        if message.exists():
+            message.close()
+        return message.exists()
 
     def change_project(self, name):
         self.topbar.user_dropdown_project.click_on_project(name)
