@@ -15,10 +15,6 @@ from selenium.webdriver.common import by
 from openstack_dashboard.test.integration_tests.regions import baseregion
 
 
-class CannotClickMenuItemException(Exception):
-    pass
-
-
 class NavigationAccordionRegion(baseregion.BaseRegion):
     """Navigation menu located in the left."""
     _project_access_security_locator = (
@@ -29,8 +25,6 @@ class NavigationAccordionRegion(baseregion.BaseRegion):
                             ".//*[@id='main_content']//div[contains(text(),"
                             "'Project')]")
 
-    MAX_MENU_ITEM_CLICK_TRIES = 100
-
     @property
     def project_bar(self):
         return self._get_element(*self._project_bar_locator)
@@ -47,9 +41,14 @@ class NavigationAccordionRegion(baseregion.BaseRegion):
         "//li[contains(concat('', @class, ''), 'nav-header') "
         "and contains(., '%s')]/a")
     _third_level_item_xpath_template = (
-        "//li[contains(concat('', @class, ''), 'openstack-panel') and "
+        ".//li[contains(concat('', @class, ''), 'openstack-panel') and "
         "contains(., '%s')]/a")
 
+    _parent_item_locator = (by.By.XPATH, '..')
+    _menu_list_locator = (by.By.CSS_SELECTOR, 'ul')
+    _expanded_menu_class = 'in'
+    _transitioning_menu_class = 'collapsing'
+
     def _get_first_level_item_locator(self, text):
         return (by.By.XPATH,
                 self._first_level_item_xpath_template % text)
@@ -82,57 +81,98 @@ class NavigationAccordionRegion(baseregion.BaseRegion):
     def change_password(self):
         return self._get_element(*self._settings_change_password_locator)
 
-    def _click_menu_item(self, text, loc_craft_func, get_selected_func=None):
+    def _wait_until_transition_ends(self, item, to_be_expanded=False):
+        def predicate(d):
+            classes = item.get_attribute('class').split()
+            if to_be_expanded:
+                status = self._expanded_menu_class in classes
+            else:
+                status = self._expanded_menu_class not in classes
+            return status and self._transitioning_menu_class not in classes
+        self._wait_until(predicate)
+
+    def _click_menu_item(self, text, loc_craft_func, get_selected_func=None,
+                         src_elem=None):
         """Click on menu item if not selected.
 
         Menu animation that visualize transition from one selection to
         another take some time - if clicked on item during this animation
-        nothing happens, therefore it is necessary to do this in a loop.
+        nothing happens, therefore it is necessary to wait for the transition
+        to complete first.
+
+        Third-level menus are handled differently from others. First, they do
+        not need to collapse other 3rd-level menu item prior to clicking them
+        (because 3rd-level menus are atomic). Second, clicking them doesn't
+        initiate an animated transition, hence no need to wait until it
+        finishes. Also an ambiguity is possible when matching third-level menu
+        items, because different dashboards have panels with the same name (for
+        example Volumes/Images/Instances both at Project and Admin dashboards).
+        To avoid this ambiguity, an argument `src_elem` is used. Whenever
+        dashboard or a panel group is clicked, its wrapper is returned to be
+        used as `src_elem` in a subsequent call for clicking third-level item.
+        This way the set of panel labels being matched is restricted to the
+        descendants of that particular dashboard or panel group.
         """
-
-        if not get_selected_func:
-            self._click_item(text, loc_craft_func)
-        else:
-            for _ in range(self.MAX_MENU_ITEM_CLICK_TRIES):
-                selected_item = get_selected_func()
-                if selected_item and text == selected_item.text:
-                    break
-
-                # In case different item was chosen previously scroll it,
-                # because otherwise selenium will complain with
-                # MoveTargetOutOfBoundsException
-                if selected_item:
+        is_already_within_required_item = False
+        selected_item = None
+        if get_selected_func is not None:
+            selected_item = get_selected_func()
+            if selected_item:
+                if text != selected_item.text:
+                    # In case different item was chosen previously, collapse
+                    # it. Otherwise selenium will complain with
+                    # MoveTargetOutOfBoundsException
                     selected_item.click()
-                self._click_item(text, loc_craft_func)
-            else:
+                    self._wait_until_transition_ends(selected_item)
+                else:
+                    is_already_within_required_item = True
 
-                # One should never get in here,
-                # this suggest that something is wrong
-                raise CannotClickMenuItemException()
+        if not is_already_within_required_item:
+            item = self._get_item(text, loc_craft_func, src_elem)
+            item.click()
+            if get_selected_func is not None:
+                self._wait_until_transition_ends(
+                    self._get_menu_list_next_to_menu_title(item),
+                    to_be_expanded=True)
+            return item
+        return selected_item
 
-    def _click_item(self, text, loc_craft_func):
-        """Click on item."""
+    def _get_item(self, text, loc_craft_func, src_elem=None):
         item_locator = loc_craft_func(text)
-        item = self._get_element(*item_locator)
-        item.click()
+        src_elem = src_elem or self.src_elem
+        return src_elem.find_element(*item_locator)
+
+    def _get_menu_list_next_to_menu_title(self, title_item):
+        parent_item = title_item.find_element(*self._parent_item_locator)
+        return parent_item.find_element(*self._menu_list_locator)
 
     def click_on_menu_items(self, first_level=None,
                             second_level=None,
                             third_level=None):
+        src_elem = None
         if first_level:
-            self._click_menu_item(first_level,
-                                  self._get_first_level_item_locator,
-                                  self.get_first_level_selected_item)
+            src_elem = self._click_menu_item(
+                first_level,
+                self._get_first_level_item_locator,
+                self.get_first_level_selected_item)
         if second_level:
-            self._click_menu_item(second_level,
-                                  self._get_second_level_item_locator,
-                                  self.get_second_level_selected_item)
+            src_elem = self._click_menu_item(
+                second_level,
+                self._get_second_level_item_locator,
+                self.get_second_level_selected_item)
 
-        # it is not checked that third level item is clicked because behaviour
-        # of the third menu layer is buggy => always click
         if third_level:
+            # NOTE(tsufiev): possible dashboard/panel group label passed as
+            # `src_elem` is a sibling of <ul> with all the panels it contains.
+            # So to get the panel within specified dashboard/panel group, we
+            # need to traverse upwards first. When `src_elem` is not specified
+            # (true for Settings pseudo-dashboard), we cannot and should not
+            # go upward.
+            if src_elem:
+                src_elem = src_elem.find_element(*self._parent_item_locator)
             self._click_menu_item(third_level,
-                                  self._get_third_level_item_locator)
+                                  self._get_third_level_item_locator,
+                                  src_elem=src_elem)
 
 
 class DropDownMenuRegion(baseregion.BaseRegion):
@@ -199,7 +239,7 @@ class UserDropDownMenuRegion(DropDownMenuRegion):
 class TabbedMenuRegion(baseregion.BaseRegion):
 
     _tab_locator = (by.By.CSS_SELECTOR, 'a')
-    _default_src_locator = (by.By.CSS_SELECTOR, 'ul.nav.nav-tabs')
+    _default_src_locator = (by.By.CSS_SELECTOR, '.selenium-nav-region')
 
     def switch_to(self, index=0):
         self._get_elements(*self._tab_locator)[index].click()
@@ -208,8 +248,8 @@ class TabbedMenuRegion(baseregion.BaseRegion):
 class ProjectDropDownRegion(DropDownMenuRegion):
 
     _menu_first_child_locator = (by.By.CSS_SELECTOR, '*')
-    _menu_items_locator = (by.By.CSS_SELECTOR,
-                           'div.context-lists a')
+    _menu_items_locator = (
+        by.By.CSS_SELECTOR, 'ul.context-selection li > a')
 
     def click_on_project(self, name):
         for item in self.menu_items:
