@@ -10,6 +10,7 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 from openstack_dashboard.test.integration_tests import helpers
+from openstack_dashboard.test.integration_tests.regions import messages
 
 
 PROJECT_NAME = helpers.gen_random_resource_name("project")
@@ -23,6 +24,15 @@ class TestCreateDeleteProject(helpers.AdminTestCase):
 
     def test_create_delete_project(self):
         self.projects_page.create_project(PROJECT_NAME)
+        self.assertTrue(
+            self.projects_page.find_message_and_dismiss(messages.SUCCESS))
+        self.assertFalse(
+            self.projects_page.find_message_and_dismiss(messages.ERROR))
         self.assertTrue(self.projects_page.is_project_present(PROJECT_NAME))
+
         self.projects_page.delete_project(PROJECT_NAME)
+        self.assertTrue(
+            self.projects_page.find_message_and_dismiss(messages.SUCCESS))
+        self.assertFalse(
+            self.projects_page.find_message_and_dismiss(messages.ERROR))
         self.assertFalse(self.projects_page.is_project_present(PROJECT_NAME))
